# -*- coding: utf-8 -*-
# ----  AUTO-GENERATED BY redox_lib_gen. DO NOT MODIFY MANUALLY!!  ---- #

from typing import List, Union

from pydantic import Field

from ..abstract_base import EventTypeAbstractModel, RedoxAbstractModel
from ..field_types import Number


class PatientPush(EventTypeAbstractModel):

    AdvanceDirectives: List["PatientPushAdvanceDirective"] = Field(None)
    AdvanceDirectivesText: Union[str, None] = Field(None)
    Allergies: List["PatientPushAllergy"] = Field(None)
    AllergyText: Union[str, None] = Field(None)
    Encounters: List["PatientPushEncounter"] = Field(None)
    EncountersText: Union[str, None] = Field(None)
    FamilyHistory: List["PatientPushFamilyHistory"] = Field(None)
    FamilyHistoryText: Union[str, None] = Field(None)
    FunctionalStatus: "PatientPushFunctionalStatus" = Field(None)
    FunctionalStatusText: Union[str, None] = Field(None)
    Goals: List["PatientPushGoal"] = Field(None)
    GoalsText: Union[str, None] = Field(None)
    Header: "PatientPushHeader" = Field(None)
    HealthConcerns: List["PatientPushHealthConcern"] = Field(None)
    HealthConcernsText: Union[str, None] = Field(None)
    Immunizations: List["PatientPushImmunization"] = Field(None)
    ImmunizationText: Union[str, None] = Field(None)
    Insurances: List["PatientPushInsurance"] = Field(None)
    InsurancesText: Union[str, None] = Field(None)
    MedicalEquipment: List["PatientPushMedicalEquipment"] = Field(None)
    MedicalEquipmentText: Union[str, None] = Field(None)
    MedicalHistoryText: Union[str, None] = Field(None)
    Medications: List["PatientPushMedication"] = Field(None)
    MedicationsText: Union[str, None] = Field(None)
    Meta: "PatientPushMeta" = Field(...)
    NoteSections: List["PatientPushNoteSection"] = Field(None)
    PlanOfCare: "PatientPushPlanOfCare" = Field(None)
    PlanOfCareText: Union[str, None] = Field(None)
    Problems: List["PatientPushProblem"] = Field(None)
    ProblemsText: Union[str, None] = Field(None)
    Procedures: "PatientPushProcedures" = Field(None)
    ProceduresText: Union[str, None] = Field(None)
    ResolvedProblems: List["PatientPushResolvedProblem"] = Field(None)
    ResolvedProblemsText: Union[str, None] = Field(None)
    Results: List["PatientPushResult"] = Field(None)
    ResultText: Union[str, None] = Field(None)
    SocialHistory: "PatientPushSocialHistory" = Field(None)
    SocialHistoryText: Union[str, None] = Field(None)
    VitalSigns: List["PatientPushVitalSign"] = Field(None)
    VitalSignsText: Union[str, None] = Field(None)


class PatientPushAdvanceDirective(RedoxAbstractModel):

    AltCodes: List["PatientPushAdvanceDirectiveAltCode"] = Field(None)
    Code: Union[str, None] = Field(None)
    CodeSystem: Union[str, None] = Field(None)
    CodeSystemName: Union[str, None] = Field(None)
    Custodians: List["PatientPushAdvanceDirectiveCustodian"] = Field(None)
    EndDate: Union[str, None] = Field(None)
    ExternalReference: Union[str, None] = Field(None)
    Name: Union[str, None] = Field(None)
    StartDate: Union[str, None] = Field(None)
    Type: "PatientPushAdvanceDirectiveType" = Field(None)
    VerifiedBy: List["PatientPushAdvanceDirectiveVerifiedBy"] = Field(None)


class PatientPushAdvanceDirectiveAltCode(RedoxAbstractModel):

    Code: Union[str, None] = Field(None)
    CodeSystem: Union[str, None] = Field(None)
    CodeSystemName: Union[str, None] = Field(None)
    Name: Union[str, None] = Field(None)


class PatientPushAdvanceDirectiveCustodian(RedoxAbstractModel):

    Address: "PatientPushAdvanceDirectiveCustodianAddress" = Field(None)
    Credentials: Union[str, None] = Field(None)
    FirstName: Union[str, None] = Field(None)
    LastName: Union[str, None] = Field(None)


class PatientPushAdvanceDirectiveCustodianAddress(RedoxAbstractModel):

    City: Union[str, None] = Field(None)
    Country: Union[str, None] = Field(None)
    State: Union[str, None] = Field(None)
    StreetAddress: Union[str, None] = Field(None)
    ZIP: Union[str, None] = Field(None)


class PatientPushAdvanceDirectiveType(RedoxAbstractModel):

    AltCodes: List["PatientPushAdvanceDirectiveTypeAltCode"] = Field(None)
    Code: Union[str, None] = Field(None)
    CodeSystem: Union[str, None] = Field(None)
    CodeSystemName: Union[str, None] = Field(None)
    Name: Union[str, None] = Field(None)


class PatientPushAdvanceDirectiveTypeAltCode(RedoxAbstractModel):

    Code: Union[str, None] = Field(None)
    CodeSystem: Union[str, None] = Field(None)
    CodeSystemName: Union[str, None] = Field(None)
    Name: Union[str, None] = Field(None)


class PatientPushAdvanceDirectiveVerifiedBy(RedoxAbstractModel):

    Credentials: Union[str, None] = Field(None)
    DateTime: Union[str, None] = Field(None)
    FirstName: Union[str, None] = Field(None)
    LastName: Union[str, None] = Field(None)


class PatientPushAllergy(RedoxAbstractModel):

    Comment: Union[str, None] = Field(None)
    Criticality: "PatientPushAllergyCriticality" = Field(None)
    EndDate: Union[str, None] = Field(None)
    Reaction: List["PatientPushAllergyReaction"] = Field(None)
    Severity: "PatientPushAllergySeverity" = Field(None)
    StartDate: Union[str, None] = Field(None)
    Status: "PatientPushAllergyStatus" = Field(None)
    Substance: "PatientPushAllergySubstance" = Field(None)
    Type: "PatientPushAllergyType" = Field(None)


class PatientPushAllergyCriticality(RedoxAbstractModel):

    Code: Union[str, None] = Field(None)
    CodeSystem: Union[str, None] = Field(None)
    CodeSystemName: Union[str, None] = Field(None)
    Name: Union[str, None] = Field(None)


class PatientPushAllergyReaction(RedoxAbstractModel):

    AltCodes: List["PatientPushAllergyReactionAltCode"] = Field(None)
    Code: Union[str, None] = Field(None)
    CodeSystem: Union[str, None] = Field(None)
    CodeSystemName: Union[str, None] = Field(None)
    Name: Union[str, None] = Field(None)
    Severity: "PatientPushAllergyReactionSeverity" = Field(None)
    Text: Union[str, None] = Field(None)


class PatientPushAllergyReactionAltCode(RedoxAbstractModel):

    Code: Union[str, None] = Field(None)
    CodeSystem: Union[str, None] = Field(None)
    CodeSystemName: Union[str, None] = Field(None)
    Name: Union[str, None] = Field(None)


class PatientPushAllergyReactionSeverity(RedoxAbstractModel):

    Code: Union[str, None] = Field(None)
    CodeSystem: Union[str, None] = Field(None)
    CodeSystemName: Union[str, None] = Field(None)
    Name: Union[str, None] = Field(None)


class PatientPushAllergySeverity(RedoxAbstractModel):

    Code: Union[str, None] = Field(None)
    CodeSystem: Union[str, None] = Field(None)
    CodeSystemName: Union[str, None] = Field(None)
    Name: Union[str, None] = Field(None)


class PatientPushAllergyStatus(RedoxAbstractModel):

    Code: Union[str, None] = Field(None)
    CodeSystem: Union[str, None] = Field(None)
    CodeSystemName: Union[str, None] = Field(None)
    Name: Union[str, None] = Field(None)


class PatientPushAllergySubstance(RedoxAbstractModel):

    AltCodes: List["PatientPushAllergySubstanceAltCode"] = Field(None)
    Code: Union[str, None] = Field(None)
    CodeSystem: Union[str, None] = Field(None)
    CodeSystemName: Union[str, None] = Field(None)
    Name: Union[str, None] = Field(None)


class PatientPushAllergySubstanceAltCode(RedoxAbstractModel):

    Code: Union[str, None] = Field(None)
    CodeSystem: Union[str, None] = Field(None)
    CodeSystemName: Union[str, None] = Field(None)
    Name: Union[str, None] = Field(None)


class PatientPushAllergyType(RedoxAbstractModel):

    AltCodes: List["PatientPushAllergyTypeAltCode"] = Field(None)
    Code: Union[str, None] = Field(None)
    CodeSystem: Union[str, None] = Field(None)
    CodeSystemName: Union[str, None] = Field(None)
    Name: Union[str, None] = Field(None)


class PatientPushAllergyTypeAltCode(RedoxAbstractModel):

    Code: Union[str, None] = Field(None)
    CodeSystem: Union[str, None] = Field(None)
    CodeSystemName: Union[str, None] = Field(None)
    Name: Union[str, None] = Field(None)


class PatientPushEncounter(RedoxAbstractModel):

    DateTime: Union[str, None] = Field(None)
    Diagnosis: List["PatientPushEncounterDiagnosis"] = Field(None)
    EndDateTime: Union[str, None] = Field(None)
    Identifiers: List["PatientPushEncounterIdentifier"] = Field(None)
    Locations: List["PatientPushEncounterLocation"] = Field(None)
    Providers: List["PatientPushEncounterProvider"] = Field(None)
    ReasonForVisit: List["PatientPushEncounterReasonForVisit"] = Field(None)
    Type: "PatientPushEncounterType" = Field(None)


class PatientPushEncounterDiagnosis(RedoxAbstractModel):

    AltCodes: List["PatientPushEncounterDiagnosisAltCode"] = Field(None)
    Code: Union[str, None] = Field(None)
    CodeSystem: Union[str, None] = Field(None)
    CodeSystemName: Union[str, None] = Field(None)
    Name: Union[str, None] = Field(None)


class PatientPushEncounterDiagnosisAltCode(RedoxAbstractModel):

    Code: Union[str, None] = Field(None)
    CodeSystem: Union[str, None] = Field(None)
    CodeSystemName: Union[str, None] = Field(None)
    Name: Union[str, None] = Field(None)


class PatientPushEncounterIdentifier(RedoxAbstractModel):

    ID: Union[str, None] = Field(None)
    IDType: Union[str, None] = Field(None)


class PatientPushEncounterLocation(RedoxAbstractModel):

    Address: "PatientPushEncounterLocationAddress" = Field(None)
    Name: Union[str, None] = Field(None)
    Type: "PatientPushEncounterLocationType" = Field(None)


class PatientPushEncounterLocationAddress(RedoxAbstractModel):

    City: Union[str, None] = Field(None)
    Country: Union[str, None] = Field(None)
    State: Union[str, None] = Field(None)
    StreetAddress: Union[str, None] = Field(None)
    ZIP: Union[str, None] = Field(None)


class PatientPushEncounterLocationType(RedoxAbstractModel):

    AltCodes: List["PatientPushEncounterLocationTypeAltCode"] = Field(None)
    Code: Union[str, None] = Field(None)
    CodeSystem: Union[str, None] = Field(None)
    CodeSystemName: Union[str, None] = Field(None)
    Name: Union[str, None] = Field(None)


class PatientPushEncounterLocationTypeAltCode(RedoxAbstractModel):

    Code: Union[str, None] = Field(None)
    CodeSystem: Union[str, None] = Field(None)
    CodeSystemName: Union[str, None] = Field(None)
    Name: Union[str, None] = Field(None)


class PatientPushEncounterProvider(RedoxAbstractModel):

    Address: "PatientPushEncounterProviderAddress" = Field(None)
    Credentials: List[str] = Field(None)
    EmailAddresses: List[str] = Field(None)
    FirstName: Union[str, None] = Field(None)
    ID: Union[str, None] = Field(None)
    IDType: Union[str, None] = Field(None)
    LastName: Union[str, None] = Field(None)
    Location: "PatientPushEncounterProviderLocation" = Field(None)
    NPI: Union[str, None] = Field(None)
    PhoneNumber: "PatientPushEncounterProviderPhoneNumber" = Field(None)
    Role: "PatientPushEncounterProviderRole" = Field(None)


class PatientPushEncounterProviderAddress(RedoxAbstractModel):

    City: Union[str, None] = Field(None)
    Country: Union[str, None] = Field(None)
    County: Union[str, None] = Field(None)
    State: Union[str, None] = Field(None)
    StreetAddress: Union[str, None] = Field(None)
    ZIP: Union[str, None] = Field(None)


class PatientPushEncounterProviderLocation(RedoxAbstractModel):

    Department: Union[str, None] = Field(None)
    Facility: Union[str, None] = Field(None)
    Room: Union[str, None] = Field(None)
    Type: Union[str, None] = Field(None)


class PatientPushEncounterProviderPhoneNumber(RedoxAbstractModel):

    Office: Union[str, None] = Field(None)


class PatientPushEncounterProviderRole(RedoxAbstractModel):

    AltCodes: List["PatientPushEncounterProviderRoleAltCode"] = Field(None)
    Code: Union[str, None] = Field(None)
    CodeSystem: Union[str, None] = Field(None)
    CodeSystemName: Union[str, None] = Field(None)
    Name: Union[str, None] = Field(None)


class PatientPushEncounterProviderRoleAltCode(RedoxAbstractModel):

    Code: Union[str, None] = Field(None)
    CodeSystem: Union[str, None] = Field(None)
    CodeSystemName: Union[str, None] = Field(None)
    Name: Union[str, None] = Field(None)


class PatientPushEncounterReasonForVisit(RedoxAbstractModel):

    AltCodes: List["PatientPushEncounterReasonForVisitAltCode"] = Field(None)
    Code: Union[str, None] = Field(None)
    CodeSystem: Union[str, None] = Field(None)
    CodeSystemName: Union[str, None] = Field(None)
    Name: Union[str, None] = Field(None)


class PatientPushEncounterReasonForVisitAltCode(RedoxAbstractModel):

    Code: Union[str, None] = Field(None)
    CodeSystem: Union[str, None] = Field(None)
    CodeSystemName: Union[str, None] = Field(None)
    Name: Union[str, None] = Field(None)


class PatientPushEncounterType(RedoxAbstractModel):

    AltCodes: List["PatientPushEncounterTypeAltCode"] = Field(None)
    Code: Union[str, None] = Field(None)
    CodeSystem: Union[str, None] = Field(None)
    CodeSystemName: Union[str, None] = Field(None)
    Name: Union[str, None] = Field(None)


class PatientPushEncounterTypeAltCode(RedoxAbstractModel):

    Code: Union[str, None] = Field(None)
    CodeSystem: Union[str, None] = Field(None)
    CodeSystemName: Union[str, None] = Field(None)
    Name: Union[str, None] = Field(None)


class PatientPushFamilyHistory(RedoxAbstractModel):

    Problems: List["PatientPushFamilyHistoryProblem"] = Field(None)
    Relation: "PatientPushFamilyHistoryRelation" = Field(None)


class PatientPushFamilyHistoryProblem(RedoxAbstractModel):

    AgeAtOnset: Union[str, None] = Field(None)
    AltCodes: List["PatientPushFamilyHistoryProblemAltCode"] = Field(None)
    Code: Union[str, None] = Field(None)
    CodeSystem: Union[str, None] = Field(None)
    CodeSystemName: Union[str, None] = Field(None)
    DateTime: Union[str, None] = Field(None)
    IsCauseOfDeath: Union[bool, None] = Field(None)
    Name: Union[str, None] = Field(None)
    Type: "PatientPushFamilyHistoryProblemType" = Field(None)


class PatientPushFamilyHistoryProblemAltCode(RedoxAbstractModel):

    Code: Union[str, None] = Field(None)
    CodeSystem: Union[str, None] = Field(None)
    CodeSystemName: Union[str, None] = Field(None)
    Name: Union[str, None] = Field(None)


class PatientPushFamilyHistoryProblemType(RedoxAbstractModel):

    Code: Union[str, None] = Field(None)
    CodeSystem: Union[str, None] = Field(None)
    CodeSystemName: Union[str, None] = Field(None)
    Name: Union[str, None] = Field(None)


class PatientPushFamilyHistoryRelation(RedoxAbstractModel):

    Code: Union[str, None] = Field(None)
    CodeSystem: Union[str, None] = Field(None)
    CodeSystemName: Union[str, None] = Field(None)
    Demographics: "PatientPushFamilyHistoryRelationDemographics" = Field(None)
    IsDeceased: Union[bool, None] = Field(None)
    Name: Union[str, None] = Field(None)


class PatientPushFamilyHistoryRelationDemographics(RedoxAbstractModel):

    DOB: Union[str, None] = Field(None)
    Sex: Union[str, None] = Field(None)


class PatientPushFunctionalStatus(RedoxAbstractModel):

    Observations: List["PatientPushFunctionalStatusObservation"] = Field(None)
    Supplies: List["PatientPushFunctionalStatusSupply"] = Field(None)


class PatientPushFunctionalStatusObservation(RedoxAbstractModel):

    AltCodes: List["PatientPushFunctionalStatusObservationAltCode"] = Field(None)
    Code: Union[str, None] = Field(None)
    CodedValue: "PatientPushFunctionalStatusObservationCodedValue" = Field(None)
    CodeSystem: Union[str, None] = Field(None)
    CodeSystemName: Union[str, None] = Field(None)
    DateTime: Union[str, None] = Field(None)
    Name: Union[str, None] = Field(None)
    ReferenceRange: "PatientPushFunctionalStatusObservationReferenceRange" = Field(None)
    Units: Union[str, None] = Field(None)
    Value: Union[str, None] = Field(None)


class PatientPushFunctionalStatusObservationAltCode(RedoxAbstractModel):

    Code: Union[str, None] = Field(None)
    CodeSystem: Union[str, None] = Field(None)
    CodeSystemName: Union[str, None] = Field(None)
    Name: Union[str, None] = Field(None)


class PatientPushFunctionalStatusObservationCodedValue(RedoxAbstractModel):

    AltCodes: List["PatientPushFunctionalStatusObservationCodedValueAltCode"] = Field(
        None
    )
    Code: Union[str, None] = Field(None)
    CodeSystem: Union[str, None] = Field(None)
    CodeSystemName: Union[str, None] = Field(None)
    Name: Union[str, None] = Field(None)


class PatientPushFunctionalStatusObservationCodedValueAltCode(RedoxAbstractModel):

    Code: Union[str, None] = Field(None)
    CodeSystem: Union[str, None] = Field(None)
    CodeSystemName: Union[str, None] = Field(None)
    Name: Union[str, None] = Field(None)


class PatientPushFunctionalStatusObservationReferenceRange(RedoxAbstractModel):

    High: Union[Number, None] = Field(None)
    Low: Union[Number, None] = Field(None)
    Text: Union[str, None] = Field(None)


class PatientPushFunctionalStatusSupply(RedoxAbstractModel):

    AltCodes: List["PatientPushFunctionalStatusSupplyAltCode"] = Field(None)
    Code: Union[str, None] = Field(None)
    CodeSystem: Union[str, None] = Field(None)
    CodeSystemName: Union[str, None] = Field(None)
    DateTime: Union[str, None] = Field(None)
    Name: Union[str, None] = Field(None)
    Status: Union[str, None] = Field(None)


class PatientPushFunctionalStatusSupplyAltCode(RedoxAbstractModel):

    Code: Union[str, None] = Field(None)
    CodeSystem: Union[str, None] = Field(None)
    CodeSystemName: Union[str, None] = Field(None)
    Name: Union[str, None] = Field(None)


class PatientPushGoal(RedoxAbstractModel):

    AchievementStatus: "PatientPushGoalAchievementStatus" = Field(None)
    AltCodes: List["PatientPushGoalAltCode"] = Field(None)
    Code: Union[str, None] = Field(None)
    CodedValue: "PatientPushGoalCodedValue" = Field(None)
    CodeSystem: Union[str, None] = Field(None)
    CodeSystemName: Union[str, None] = Field(None)
    DateTime: Union[str, None] = Field(None)
    EndDate: Union[str, None] = Field(None)
    Milestones: List["PatientPushGoalMilestone"] = Field(None)
    Name: Union[str, None] = Field(None)
    Priority: "PatientPushGoalPriority" = Field(None)
    StartDate: Union[str, None] = Field(None)
    Units: Union[str, None] = Field(None)
    Value: Union[str, None] = Field(None)


class PatientPushGoalAchievementStatus(RedoxAbstractModel):

    Code: Union[str, None] = Field(None)
    CodeSystem: Union[str, None] = Field(None)
    CodeSystemName: Union[str, None] = Field(None)
    Name: Union[str, None] = Field(None)


class PatientPushGoalAltCode(RedoxAbstractModel):

    Code: Union[str, None] = Field(None)
    CodeSystem: Union[str, None] = Field(None)
    CodeSystemName: Union[str, None] = Field(None)
    Name: Union[str, None] = Field(None)


class PatientPushGoalCodedValue(RedoxAbstractModel):

    AltCodes: List["PatientPushGoalCodedValueAltCode"] = Field(None)
    Code: Union[str, None] = Field(None)
    CodeSystem: Union[str, None] = Field(None)
    CodeSystemName: Union[str, None] = Field(None)
    Name: Union[str, None] = Field(None)


class PatientPushGoalCodedValueAltCode(RedoxAbstractModel):

    Code: Union[str, None] = Field(None)
    CodeSystem: Union[str, None] = Field(None)
    CodeSystemName: Union[str, None] = Field(None)
    Name: Union[str, None] = Field(None)


class PatientPushGoalMilestone(RedoxAbstractModel):

    AchievementStatus: "PatientPushGoalMilestoneAchievementStatus" = Field(None)
    AltCodes: List["PatientPushGoalMilestoneAltCode"] = Field(None)
    Code: Union[str, None] = Field(None)
    CodedValue: "PatientPushGoalMilestoneCodedValue" = Field(None)
    CodeSystem: Union[str, None] = Field(None)
    CodeSystemName: Union[str, None] = Field(None)
    DateTime: Union[str, None] = Field(None)
    EndDate: Union[str, None] = Field(None)
    Name: Union[str, None] = Field(None)
    Priority: "PatientPushGoalMilestonePriority" = Field(None)
    StartDate: Union[str, None] = Field(None)
    Units: Union[str, None] = Field(None)
    Value: Union[str, None] = Field(None)


class PatientPushGoalMilestoneAchievementStatus(RedoxAbstractModel):

    Code: Union[str, None] = Field(None)
    CodeSystem: Union[str, None] = Field(None)
    CodeSystemName: Union[str, None] = Field(None)
    Name: Union[str, None] = Field(None)


class PatientPushGoalMilestoneAltCode(RedoxAbstractModel):

    Code: Union[str, None] = Field(None)
    CodeSystem: Union[str, None] = Field(None)
    CodeSystemName: Union[str, None] = Field(None)
    Name: Union[str, None] = Field(None)


class PatientPushGoalMilestoneCodedValue(RedoxAbstractModel):

    AltCodes: List["PatientPushGoalMilestoneCodedValueAltCode"] = Field(None)
    Code: Union[str, None] = Field(None)
    CodeSystem: Union[str, None] = Field(None)
    CodeSystemName: Union[str, None] = Field(None)
    Name: Union[str, None] = Field(None)


class PatientPushGoalMilestoneCodedValueAltCode(RedoxAbstractModel):

    Code: Union[str, None] = Field(None)
    CodeSystem: Union[str, None] = Field(None)
    CodeSystemName: Union[str, None] = Field(None)
    Name: Union[str, None] = Field(None)


class PatientPushGoalMilestonePriority(RedoxAbstractModel):

    Code: Union[str, None] = Field(None)
    CodeSystem: Union[str, None] = Field(None)
    CodeSystemName: Union[str, None] = Field(None)
    Name: Union[str, None] = Field(None)


class PatientPushGoalPriority(RedoxAbstractModel):

    Code: Union[str, None] = Field(None)
    CodeSystem: Union[str, None] = Field(None)
    CodeSystemName: Union[str, None] = Field(None)
    Name: Union[str, None] = Field(None)


class PatientPushHeader(RedoxAbstractModel):

    DirectAddressFrom: Union[None] = Field(None)
    DirectAddressTo: Union[None] = Field(None)
    Document: "PatientPushHeaderDocument" = Field(None)
    Patient: "PatientPushHeaderPatient" = Field(None)
    PCP: "PatientPushHeaderPCP" = Field(None)


class PatientPushHeaderDocument(RedoxAbstractModel):

    Author: "PatientPushHeaderDocumentAuthor" = Field(None)
    Custodian: "PatientPushHeaderDocumentCustodian" = Field(None)
    DateTime: Union[str, None] = Field(None)
    ID: Union[str, None] = Field(None)
    Locale: Union[str, None] = Field(None)
    Title: Union[str, None] = Field(None)
    Type: Union[str, None] = Field(None)
    TypeCode: "PatientPushHeaderDocumentTypeCode" = Field(None)
    Visit: "PatientPushHeaderDocumentVisit" = Field(None)


class PatientPushHeaderDocumentAuthor(RedoxAbstractModel):

    Address: "PatientPushHeaderDocumentAuthorAddress" = Field(None)
    Credentials: List[str] = Field(None)
    EmailAddresses: List[str] = Field(None)
    FirstName: Union[str, None] = Field(None)
    ID: Union[str, None] = Field(None)
    IDType: Union[str, None] = Field(None)
    LastName: Union[str, None] = Field(None)
    Location: "PatientPushHeaderDocumentAuthorLocation" = Field(None)
    PhoneNumber: "PatientPushHeaderDocumentAuthorPhoneNumber" = Field(None)
    Type: Union[str, None] = Field(None)


class PatientPushHeaderDocumentAuthorAddress(RedoxAbstractModel):

    City: Union[str, None] = Field(None)
    Country: Union[str, None] = Field(None)
    County: Union[str, None] = Field(None)
    State: Union[str, None] = Field(None)
    StreetAddress: Union[str, None] = Field(None)
    ZIP: Union[str, None] = Field(None)


class PatientPushHeaderDocumentAuthorLocation(RedoxAbstractModel):

    Department: Union[str, None] = Field(None)
    Facility: Union[str, None] = Field(None)
    Room: Union[str, None] = Field(None)
    Type: Union[str, None] = Field(None)


class PatientPushHeaderDocumentAuthorPhoneNumber(RedoxAbstractModel):

    Office: Union[str, None] = Field(None)


class PatientPushHeaderDocumentCustodian(RedoxAbstractModel):

    Address: "PatientPushHeaderDocumentCustodianAddress" = Field(None)
    Identifiers: List["PatientPushHeaderDocumentCustodianIdentifier"] = Field(None)
    Name: Union[None] = Field(None)
    Telecom: List["PatientPushHeaderDocumentCustodianTelecom"] = Field(None)
    Type: "PatientPushHeaderDocumentCustodianType" = Field(None)


class PatientPushHeaderDocumentCustodianAddress(RedoxAbstractModel):

    City: Union[str, None] = Field(None)
    Country: Union[str, None] = Field(None)
    County: Union[str, None] = Field(None)
    State: Union[str, None] = Field(None)
    StreetAddress: Union[str, None] = Field(None)
    ZIP: Union[str, None] = Field(None)


class PatientPushHeaderDocumentCustodianIdentifier(RedoxAbstractModel):

    ID: Union[str, None] = Field(None)
    IDType: Union[str, None] = Field(None)


class PatientPushHeaderDocumentCustodianTelecom(RedoxAbstractModel):

    System: Union[None] = Field(None)
    Use: Union[None] = Field(None)
    Value: Union[None] = Field(None)


class PatientPushHeaderDocumentCustodianType(RedoxAbstractModel):

    AltCodes: List["PatientPushHeaderDocumentCustodianTypeAltCode"] = Field(None)
    Code: Union[str, None] = Field(None)
    CodeSystem: Union[str, None] = Field(None)
    CodeSystemName: Union[str, None] = Field(None)
    Name: Union[str, None] = Field(None)


class PatientPushHeaderDocumentCustodianTypeAltCode(RedoxAbstractModel):

    Code: Union[str, None] = Field(None)
    CodeSystem: Union[str, None] = Field(None)
    CodeSystemName: Union[str, None] = Field(None)
    Name: Union[str, None] = Field(None)


class PatientPushHeaderDocumentTypeCode(RedoxAbstractModel):

    Code: Union[str, None] = Field(None)
    CodeSystem: Union[str, None] = Field(None)
    CodeSystemName: Union[str, None] = Field(None)
    Name: Union[str, None] = Field(None)


class PatientPushHeaderDocumentVisit(RedoxAbstractModel):

    EndDateTime: Union[str, None] = Field(None)
    Location: "PatientPushHeaderDocumentVisitLocation" = Field(None)
    Reason: Union[str, None] = Field(None)
    StartDateTime: Union[str, None] = Field(None)
    Type: "PatientPushHeaderDocumentVisitType" = Field(None)
    VisitNumber: Union[str, None] = Field(None)


class PatientPushHeaderDocumentVisitLocation(RedoxAbstractModel):

    Department: Union[str, None] = Field(None)
    Facility: Union[str, None] = Field(None)
    Room: Union[str, None] = Field(None)
    Type: Union[str, None] = Field(None)


class PatientPushHeaderDocumentVisitType(RedoxAbstractModel):

    AltCodes: List["PatientPushHeaderDocumentVisitTypeAltCode"] = Field(None)
    Code: Union[str, None] = Field(None)
    CodeSystem: Union[str, None] = Field(None)
    CodeSystemName: Union[str, None] = Field(None)
    Name: Union[str, None] = Field(None)


class PatientPushHeaderDocumentVisitTypeAltCode(RedoxAbstractModel):

    Code: Union[str, None] = Field(None)
    CodeSystem: Union[str, None] = Field(None)
    CodeSystemName: Union[str, None] = Field(None)
    Name: Union[str, None] = Field(None)


class PatientPushHeaderPatient(RedoxAbstractModel):

    Demographics: "PatientPushHeaderPatientDemographics" = Field(None)
    Identifiers: List["PatientPushHeaderPatientIdentifier"] = Field(None)
    Organization: "PatientPushHeaderPatientOrganization" = Field(None)


class PatientPushHeaderPatientDemographics(RedoxAbstractModel):

    Address: "PatientPushHeaderPatientDemographicsAddress" = Field(None)
    DeathDateTime: Union[str, None] = Field(None)
    DOB: Union[str, None] = Field(None)
    EmailAddresses: List["PatientPushHeaderPatientDemographicsEmailAddress"] = Field(
        None
    )
    EthnicGroupCodes: List[
        "PatientPushHeaderPatientDemographicsEthnicGroupCode"
    ] = Field(None)
    Ethnicity: Union[str, None] = Field(None)
    FirstName: Union[str, None] = Field(None)
    IsDeceased: Union[bool, None] = Field(None)
    Language: Union[str, None] = Field(None)
    LastName: Union[str, None] = Field(None)
    MaritalStatus: Union[str, None] = Field(None)
    MiddleName: Union[str, None] = Field(None)
    PhoneNumber: "PatientPushHeaderPatientDemographicsPhoneNumber" = Field(None)
    Race: Union[str, None] = Field(None)
    RaceCodes: List["PatientPushHeaderPatientDemographicsRaceCode"] = Field(None)
    Religion: Union[str, None] = Field(None)
    Sex: Union[str, None] = Field(None)
    SSN: Union[str, None] = Field(None)


class PatientPushHeaderPatientDemographicsAddress(RedoxAbstractModel):

    City: Union[str, None] = Field(None)
    Country: Union[str, None] = Field(None)
    County: Union[str, None] = Field(None)
    State: Union[str, None] = Field(None)
    StreetAddress: Union[str, None] = Field(None)
    ZIP: Union[str, None] = Field(None)


class PatientPushHeaderPatientDemographicsEmailAddress(RedoxAbstractModel):

    Address: Union[str, None] = Field(None)


class PatientPushHeaderPatientDemographicsEthnicGroupCode(RedoxAbstractModel):

    Code: Union[str, None] = Field(None)
    CodeSystem: Union[str, None] = Field(None)
    CodeSystemName: Union[str, None] = Field(None)
    Name: Union[str, None] = Field(None)


class PatientPushHeaderPatientDemographicsPhoneNumber(RedoxAbstractModel):

    Home: Union[str, None] = Field(None)
    Mobile: Union[str, None] = Field(None)


class PatientPushHeaderPatientDemographicsRaceCode(RedoxAbstractModel):

    Code: Union[str, None] = Field(None)
    CodeSystem: Union[str, None] = Field(None)
    CodeSystemName: Union[str, None] = Field(None)
    Name: Union[str, None] = Field(None)


class PatientPushHeaderPatientIdentifier(RedoxAbstractModel):

    ID: Union[str, None] = Field(None)
    IDType: Union[str, None] = Field(None)
    Type: Union[str, None] = Field(None)


class PatientPushHeaderPatientOrganization(RedoxAbstractModel):

    Address: "PatientPushHeaderPatientOrganizationAddress" = Field(None)
    Identifiers: List["PatientPushHeaderPatientOrganizationIdentifier"] = Field(None)
    Name: Union[None] = Field(None)
    Telecom: List["PatientPushHeaderPatientOrganizationTelecom"] = Field(None)
    Type: "PatientPushHeaderPatientOrganizationType" = Field(None)


class PatientPushHeaderPatientOrganizationAddress(RedoxAbstractModel):

    City: Union[str, None] = Field(None)
    Country: Union[str, None] = Field(None)
    County: Union[str, None] = Field(None)
    State: Union[str, None] = Field(None)
    StreetAddress: Union[str, None] = Field(None)
    ZIP: Union[str, None] = Field(None)


class PatientPushHeaderPatientOrganizationIdentifier(RedoxAbstractModel):

    ID: Union[str, None] = Field(None)
    IDType: Union[str, None] = Field(None)


class PatientPushHeaderPatientOrganizationTelecom(RedoxAbstractModel):

    System: Union[None] = Field(None)
    Use: Union[None] = Field(None)
    Value: Union[None] = Field(None)


class PatientPushHeaderPatientOrganizationType(RedoxAbstractModel):

    AltCodes: List["PatientPushHeaderPatientOrganizationTypeAltCode"] = Field(None)
    Code: Union[str, None] = Field(None)
    CodeSystem: Union[str, None] = Field(None)
    CodeSystemName: Union[str, None] = Field(None)
    Name: Union[str, None] = Field(None)


class PatientPushHeaderPatientOrganizationTypeAltCode(RedoxAbstractModel):

    Code: Union[str, None] = Field(None)
    CodeSystem: Union[str, None] = Field(None)
    CodeSystemName: Union[str, None] = Field(None)
    Name: Union[str, None] = Field(None)


class PatientPushHeaderPCP(RedoxAbstractModel):

    Address: "PatientPushHeaderPCPAddress" = Field(None)
    Credentials: List[str] = Field(None)
    EmailAddresses: List[str] = Field(None)
    FirstName: Union[str, None] = Field(None)
    ID: Union[str, None] = Field(None)
    IDType: Union[str, None] = Field(None)
    LastName: Union[str, None] = Field(None)
    Location: "PatientPushHeaderPCPLocation" = Field(None)
    PhoneNumber: "PatientPushHeaderPCPPhoneNumber" = Field(None)
    Type: Union[str, None] = Field(None)


class PatientPushHeaderPCPAddress(RedoxAbstractModel):

    City: Union[str, None] = Field(None)
    Country: Union[str, None] = Field(None)
    County: Union[str, None] = Field(None)
    State: Union[str, None] = Field(None)
    StreetAddress: Union[str, None] = Field(None)
    ZIP: Union[str, None] = Field(None)


class PatientPushHeaderPCPLocation(RedoxAbstractModel):

    Department: Union[str, None] = Field(None)
    Facility: Union[str, None] = Field(None)
    Room: Union[str, None] = Field(None)
    Type: Union[str, None] = Field(None)


class PatientPushHeaderPCPPhoneNumber(RedoxAbstractModel):

    Office: Union[str, None] = Field(None)


class PatientPushHealthConcern(RedoxAbstractModel):

    AltCodes: List["PatientPushHealthConcernAltCode"] = Field(None)
    Code: Union[str, None] = Field(None)
    CodeSystem: Union[str, None] = Field(None)
    CodeSystemName: Union[str, None] = Field(None)
    EndDate: Union[str, None] = Field(None)
    Name: Union[str, None] = Field(None)
    StartDate: Union[str, None] = Field(None)
    Status: Union[str, None] = Field(None)


class PatientPushHealthConcernAltCode(RedoxAbstractModel):

    Code: Union[str, None] = Field(None)
    CodeSystem: Union[str, None] = Field(None)
    CodeSystemName: Union[str, None] = Field(None)
    Name: Union[str, None] = Field(None)


class PatientPushImmunization(RedoxAbstractModel):

    DateTime: Union[str, None] = Field(None)
    Dose: "PatientPushImmunizationDose" = Field(None)
    Product: "PatientPushImmunizationProduct" = Field(None)
    Route: "PatientPushImmunizationRoute" = Field(None)


class PatientPushImmunizationDose(RedoxAbstractModel):

    Quantity: Union[str, None] = Field(None)
    Units: Union[str, None] = Field(None)


class PatientPushImmunizationProduct(RedoxAbstractModel):

    AltCodes: List["PatientPushImmunizationProductAltCode"] = Field(None)
    Code: Union[str, None] = Field(None)
    CodeSystem: Union[str, None] = Field(None)
    CodeSystemName: Union[str, None] = Field(None)
    LotNumber: Union[str, None] = Field(None)
    Manufacturer: Union[str, None] = Field(None)
    Name: Union[str, None] = Field(None)


class PatientPushImmunizationProductAltCode(RedoxAbstractModel):

    Code: Union[str, None] = Field(None)
    CodeSystem: Union[str, None] = Field(None)
    CodeSystemName: Union[str, None] = Field(None)
    Name: Union[str, None] = Field(None)


class PatientPushImmunizationRoute(RedoxAbstractModel):

    AltCodes: List["PatientPushImmunizationRouteAltCode"] = Field(None)
    Code: Union[str, None] = Field(None)
    CodeSystem: Union[str, None] = Field(None)
    CodeSystemName: Union[str, None] = Field(None)
    Name: Union[str, None] = Field(None)


class PatientPushImmunizationRouteAltCode(RedoxAbstractModel):

    Code: Union[str, None] = Field(None)
    CodeSystem: Union[str, None] = Field(None)
    CodeSystemName: Union[str, None] = Field(None)
    Name: Union[str, None] = Field(None)


class PatientPushInsurance(RedoxAbstractModel):

    AgreementType: Union[str, None] = Field(None)
    Company: "PatientPushInsuranceCompany" = Field(None)
    CoverageType: Union[str, None] = Field(None)
    EffectiveDate: Union[str, None] = Field(None)
    ExpirationDate: Union[str, None] = Field(None)
    GroupName: Union[str, None] = Field(None)
    GroupNumber: Union[str, None] = Field(None)
    Insured: "PatientPushInsuranceInsured" = Field(None)
    MemberNumber: Union[str, None] = Field(None)
    Plan: "PatientPushInsurancePlan" = Field(None)
    PolicyNumber: Union[str, None] = Field(None)
    Priority: Union[str, None] = Field(None)


class PatientPushInsuranceCompany(RedoxAbstractModel):

    Address: "PatientPushInsuranceCompanyAddress" = Field(None)
    ID: Union[str, None] = Field(None)
    IDType: Union[str, None] = Field(None)
    Name: Union[str, None] = Field(None)
    PhoneNumber: Union[str, None] = Field(None)


class PatientPushInsuranceCompanyAddress(RedoxAbstractModel):

    City: Union[str, None] = Field(None)
    Country: Union[str, None] = Field(None)
    County: Union[str, None] = Field(None)
    State: Union[str, None] = Field(None)
    StreetAddress: Union[str, None] = Field(None)
    ZIP: Union[str, None] = Field(None)


class PatientPushInsuranceInsured(RedoxAbstractModel):

    Address: "PatientPushInsuranceInsuredAddress" = Field(None)
    DOB: Union[str, None] = Field(None)
    FirstName: Union[str, None] = Field(None)
    Identifiers: List["PatientPushInsuranceInsuredIdentifier"] = Field(None)
    LastName: Union[str, None] = Field(None)
    MiddleName: Union[str, None] = Field(None)
    Relationship: Union[str, None] = Field(None)
    Sex: Union[str, None] = Field(None)
    SSN: Union[str, None] = Field(None)


class PatientPushInsuranceInsuredAddress(RedoxAbstractModel):

    City: Union[str, None] = Field(None)
    Country: Union[str, None] = Field(None)
    County: Union[str, None] = Field(None)
    State: Union[str, None] = Field(None)
    StreetAddress: Union[str, None] = Field(None)
    ZIP: Union[str, None] = Field(None)


class PatientPushInsuranceInsuredIdentifier(RedoxAbstractModel):

    ID: Union[str, None] = Field(None)
    IDType: Union[str, None] = Field(None)


class PatientPushInsurancePlan(RedoxAbstractModel):

    ID: Union[str, None] = Field(None)
    IDType: Union[str, None] = Field(None)
    Name: Union[str, None] = Field(None)
    Type: Union[str, None] = Field(None)


class PatientPushMedicalEquipment(RedoxAbstractModel):

    Product: "PatientPushMedicalEquipmentProduct" = Field(None)
    Quantity: Union[str, None] = Field(None)
    StartDate: Union[str, None] = Field(None)
    Status: Union[str, None] = Field(None)


class PatientPushMedicalEquipmentProduct(RedoxAbstractModel):

    AltCodes: List["PatientPushMedicalEquipmentProductAltCode"] = Field(None)
    Code: Union[str, None] = Field(None)
    CodeSystem: Union[str, None] = Field(None)
    CodeSystemName: Union[str, None] = Field(None)
    Name: Union[str, None] = Field(None)


class PatientPushMedicalEquipmentProductAltCode(RedoxAbstractModel):

    Code: Union[str, None] = Field(None)
    CodeSystem: Union[str, None] = Field(None)
    CodeSystemName: Union[str, None] = Field(None)
    Name: Union[str, None] = Field(None)


class PatientPushMedication(RedoxAbstractModel):

    Dose: "PatientPushMedicationDose" = Field(None)
    EndDate: Union[str, None] = Field(None)
    FreeTextSig: Union[str, None] = Field(None)
    Frequency: "PatientPushMedicationFrequency" = Field(None)
    Indications: List["PatientPushMedicationIndication"] = Field(None)
    IsPRN: Union[bool, None] = Field(None)
    NumberOfRefillsRemaining: Union[Number, None] = Field(None)
    Prescription: Union[bool, None] = Field(None)
    Product: "PatientPushMedicationProduct" = Field(None)
    Rate: "PatientPushMedicationRate" = Field(None)
    Route: "PatientPushMedicationRoute" = Field(None)
    StartDate: Union[str, None] = Field(None)
    Status: Union[str, None] = Field(None)
    SupplyOrder: "PatientPushMedicationSupplyOrder" = Field(None)


class PatientPushMedicationDose(RedoxAbstractModel):

    Quantity: Union[str, None] = Field(None)
    Units: Union[str, None] = Field(None)


class PatientPushMedicationFrequency(RedoxAbstractModel):

    EventCode: Union[str, None] = Field(None)
    InstitutionSpecified: Union[bool, None] = Field(None)
    Period: Union[str, None] = Field(None)
    PeriodMax: Union[str, None] = Field(None)
    Unit: Union[str, None] = Field(None)


class PatientPushMedicationIndication(RedoxAbstractModel):

    AltCodes: List["PatientPushMedicationIndicationAltCode"] = Field(None)
    Code: Union[str, None] = Field(None)
    CodeSystem: Union[str, None] = Field(None)
    CodeSystemName: Union[str, None] = Field(None)
    Name: Union[str, None] = Field(None)


class PatientPushMedicationIndicationAltCode(RedoxAbstractModel):

    Code: Union[str, None] = Field(None)
    CodeSystem: Union[str, None] = Field(None)
    CodeSystemName: Union[str, None] = Field(None)
    Name: Union[str, None] = Field(None)


class PatientPushMedicationProduct(RedoxAbstractModel):

    AltCodes: List["PatientPushMedicationProductAltCode"] = Field(None)
    Code: Union[str, None] = Field(None)
    CodeSystem: Union[str, None] = Field(None)
    CodeSystemName: Union[str, None] = Field(None)
    Name: Union[str, None] = Field(None)


class PatientPushMedicationProductAltCode(RedoxAbstractModel):

    Code: Union[str, None] = Field(None)
    CodeSystem: Union[str, None] = Field(None)
    CodeSystemName: Union[str, None] = Field(None)
    Name: Union[str, None] = Field(None)


class PatientPushMedicationRate(RedoxAbstractModel):

    Quantity: Union[str, None] = Field(None)
    Units: Union[str, None] = Field(None)


class PatientPushMedicationRoute(RedoxAbstractModel):

    AltCodes: List["PatientPushMedicationRouteAltCode"] = Field(None)
    Code: Union[str, None] = Field(None)
    CodeSystem: Union[str, None] = Field(None)
    CodeSystemName: Union[str, None] = Field(None)
    Name: Union[str, None] = Field(None)


class PatientPushMedicationRouteAltCode(RedoxAbstractModel):

    Code: Union[str, None] = Field(None)
    CodeSystem: Union[str, None] = Field(None)
    CodeSystemName: Union[str, None] = Field(None)
    Name: Union[str, None] = Field(None)


class PatientPushMedicationSupplyOrder(RedoxAbstractModel):

    EndDate: Union[str, None] = Field(None)
    NumberOfRefillsRemaining: Union[Number, None] = Field(None)
    Quantity: Union[str, None] = Field(None)
    StartDate: Union[str, None] = Field(None)
    Units: Union[str, None] = Field(None)


class PatientPushMeta(RedoxAbstractModel):

    DataModel: str = Field(...)
    Destinations: List["PatientPushMetaDestination"] = Field(None)
    EventDateTime: Union[str, None] = Field(None)
    EventType: str = Field(...)
    FacilityCode: Union[str, None] = Field(None)
    Logs: List["PatientPushMetaLog"] = Field(None)
    Message: "PatientPushMetaMessage" = Field(None)
    Source: "PatientPushMetaSource" = Field(None)
    Test: Union[bool, None] = Field(None)
    Transmission: "PatientPushMetaTransmission" = Field(None)


class PatientPushMetaDestination(RedoxAbstractModel):

    ID: Union[str, None] = Field(None)
    Name: Union[str, None] = Field(None)


class PatientPushMetaLog(RedoxAbstractModel):

    AttemptID: Union[str, None] = Field(None)
    ID: Union[str, None] = Field(None)


class PatientPushMetaMessage(RedoxAbstractModel):

    ID: Union[Number, None] = Field(None)


class PatientPushMetaSource(RedoxAbstractModel):

    ID: Union[str, None] = Field(None)
    Name: Union[str, None] = Field(None)


class PatientPushMetaTransmission(RedoxAbstractModel):

    ID: Union[Number, None] = Field(None)


class PatientPushNoteSection(RedoxAbstractModel):

    AltCodes: List["PatientPushNoteSectionAltCode"] = Field(None)
    Code: Union[str, None] = Field(None)
    CodeSystem: Union[str, None] = Field(None)
    CodeSystemName: Union[str, None] = Field(None)
    Name: Union[str, None] = Field(None)
    Notes: List["PatientPushNoteSectionNote"] = Field(None)
    Text: Union[str, None] = Field(None)
    Title: Union[str, None] = Field(None)


class PatientPushNoteSectionAltCode(RedoxAbstractModel):

    Code: Union[str, None] = Field(None)
    CodeSystem: Union[str, None] = Field(None)
    CodeSystemName: Union[str, None] = Field(None)
    Name: Union[str, None] = Field(None)


class PatientPushNoteSectionNote(RedoxAbstractModel):

    AltCodes: List["PatientPushNoteSectionNoteAltCode"] = Field(None)
    Code: Union[str, None] = Field(None)
    CodeSystem: Union[str, None] = Field(None)
    CodeSystemName: Union[str, None] = Field(None)
    ContentType: Union[str, None] = Field(None)
    DateTime: Union[str, None] = Field(None)
    Encounter: "PatientPushNoteSectionNoteEncounter" = Field(None)
    FileContents: Union[str, None] = Field(None)
    Name: Union[str, None] = Field(None)
    Status: Union[str, None] = Field(None)


class PatientPushNoteSectionNoteAltCode(RedoxAbstractModel):

    Code: Union[str, None] = Field(None)
    CodeSystem: Union[str, None] = Field(None)
    CodeSystemName: Union[str, None] = Field(None)
    Name: Union[str, None] = Field(None)


class PatientPushNoteSectionNoteEncounter(RedoxAbstractModel):

    DateTime: Union[str, None] = Field(None)
    EndDateTime: Union[str, None] = Field(None)
    Identifiers: List["PatientPushNoteSectionNoteEncounterIdentifier"] = Field(None)
    Type: "PatientPushNoteSectionNoteEncounterType" = Field(None)


class PatientPushNoteSectionNoteEncounterIdentifier(RedoxAbstractModel):

    ID: Union[str, None] = Field(None)
    IDType: Union[str, None] = Field(None)


class PatientPushNoteSectionNoteEncounterType(RedoxAbstractModel):

    AltCodes: List["PatientPushNoteSectionNoteEncounterTypeAltCode"] = Field(None)
    Code: Union[str, None] = Field(None)
    CodeSystem: Union[str, None] = Field(None)
    CodeSystemName: Union[str, None] = Field(None)
    Name: Union[str, None] = Field(None)


class PatientPushNoteSectionNoteEncounterTypeAltCode(RedoxAbstractModel):

    Code: Union[str, None] = Field(None)
    CodeSystem: Union[str, None] = Field(None)
    CodeSystemName: Union[str, None] = Field(None)
    Name: Union[str, None] = Field(None)


class PatientPushPlanOfCare(RedoxAbstractModel):

    Encounters: List["PatientPushPlanOfCareEncounter"] = Field(None)
    MedicationAdministration: List[
        "PatientPushPlanOfCareMedicationAdministration"
    ] = Field(None)
    Orders: List["PatientPushPlanOfCareOrder"] = Field(None)
    Procedures: List["PatientPushPlanOfCareProcedure"] = Field(None)
    Services: List["PatientPushPlanOfCareService"] = Field(None)
    Supplies: List["PatientPushPlanOfCareSupply"] = Field(None)


class PatientPushPlanOfCareEncounter(RedoxAbstractModel):

    AltCodes: List["PatientPushPlanOfCareEncounterAltCode"] = Field(None)
    Code: Union[str, None] = Field(None)
    CodeSystem: Union[str, None] = Field(None)
    CodeSystemName: Union[str, None] = Field(None)
    DateTime: Union[str, None] = Field(None)
    Identifiers: List["PatientPushPlanOfCareEncounterIdentifier"] = Field(None)
    Name: Union[str, None] = Field(None)
    Status: Union[str, None] = Field(None)


class PatientPushPlanOfCareEncounterAltCode(RedoxAbstractModel):

    Code: Union[str, None] = Field(None)
    CodeSystem: Union[str, None] = Field(None)
    CodeSystemName: Union[str, None] = Field(None)
    Name: Union[str, None] = Field(None)


class PatientPushPlanOfCareEncounterIdentifier(RedoxAbstractModel):

    ID: Union[str, None] = Field(None)
    IDType: Union[str, None] = Field(None)


class PatientPushPlanOfCareMedicationAdministration(RedoxAbstractModel):

    Dose: "PatientPushPlanOfCareMedicationAdministrationDose" = Field(None)
    EndDate: Union[str, None] = Field(None)
    Frequency: "PatientPushPlanOfCareMedicationAdministrationFrequency" = Field(None)
    Product: "PatientPushPlanOfCareMedicationAdministrationProduct" = Field(None)
    Rate: "PatientPushPlanOfCareMedicationAdministrationRate" = Field(None)
    Route: "PatientPushPlanOfCareMedicationAdministrationRoute" = Field(None)
    StartDate: Union[str, None] = Field(None)
    Status: Union[str, None] = Field(None)


class PatientPushPlanOfCareMedicationAdministrationDose(RedoxAbstractModel):

    Quantity: Union[str, None] = Field(None)
    Units: Union[str, None] = Field(None)


class PatientPushPlanOfCareMedicationAdministrationFrequency(RedoxAbstractModel):

    Period: Union[str, None] = Field(None)
    Unit: Union[str, None] = Field(None)


class PatientPushPlanOfCareMedicationAdministrationProduct(RedoxAbstractModel):

    AltCodes: List[
        "PatientPushPlanOfCareMedicationAdministrationProductAltCode"
    ] = Field(None)
    Code: Union[str, None] = Field(None)
    CodeSystem: Union[str, None] = Field(None)
    CodeSystemName: Union[str, None] = Field(None)
    Name: Union[str, None] = Field(None)


class PatientPushPlanOfCareMedicationAdministrationProductAltCode(RedoxAbstractModel):

    Code: Union[str, None] = Field(None)
    CodeSystem: Union[str, None] = Field(None)
    CodeSystemName: Union[str, None] = Field(None)
    Name: Union[str, None] = Field(None)


class PatientPushPlanOfCareMedicationAdministrationRate(RedoxAbstractModel):

    Quantity: Union[str, None] = Field(None)
    Units: Union[str, None] = Field(None)


class PatientPushPlanOfCareMedicationAdministrationRoute(RedoxAbstractModel):

    AltCodes: List["PatientPushPlanOfCareMedicationAdministrationRouteAltCode"] = Field(
        None
    )
    Code: Union[str, None] = Field(None)
    CodeSystem: Union[str, None] = Field(None)
    CodeSystemName: Union[str, None] = Field(None)
    Name: Union[str, None] = Field(None)


class PatientPushPlanOfCareMedicationAdministrationRouteAltCode(RedoxAbstractModel):

    Code: Union[str, None] = Field(None)
    CodeSystem: Union[str, None] = Field(None)
    CodeSystemName: Union[str, None] = Field(None)
    Name: Union[str, None] = Field(None)


class PatientPushPlanOfCareOrder(RedoxAbstractModel):

    AltCodes: List["PatientPushPlanOfCareOrderAltCode"] = Field(None)
    Code: Union[str, None] = Field(None)
    CodeSystem: Union[str, None] = Field(None)
    CodeSystemName: Union[str, None] = Field(None)
    DateTime: Union[str, None] = Field(None)
    Name: Union[str, None] = Field(None)
    Status: Union[str, None] = Field(None)


class PatientPushPlanOfCareOrderAltCode(RedoxAbstractModel):

    Code: Union[str, None] = Field(None)
    CodeSystem: Union[str, None] = Field(None)
    CodeSystemName: Union[str, None] = Field(None)
    Name: Union[str, None] = Field(None)


class PatientPushPlanOfCareProcedure(RedoxAbstractModel):

    AltCodes: List["PatientPushPlanOfCareProcedureAltCode"] = Field(None)
    Code: Union[str, None] = Field(None)
    CodeSystem: Union[str, None] = Field(None)
    CodeSystemName: Union[str, None] = Field(None)
    DateTime: Union[str, None] = Field(None)
    Name: Union[str, None] = Field(None)
    Status: Union[str, None] = Field(None)


class PatientPushPlanOfCareProcedureAltCode(RedoxAbstractModel):

    Code: Union[str, None] = Field(None)
    CodeSystem: Union[str, None] = Field(None)
    CodeSystemName: Union[str, None] = Field(None)
    Name: Union[str, None] = Field(None)


class PatientPushPlanOfCareService(RedoxAbstractModel):

    AltCodes: List["PatientPushPlanOfCareServiceAltCode"] = Field(None)
    Code: Union[str, None] = Field(None)
    CodeSystem: Union[str, None] = Field(None)
    CodeSystemName: Union[str, None] = Field(None)
    DateTime: Union[str, None] = Field(None)
    Name: Union[str, None] = Field(None)
    Status: Union[str, None] = Field(None)


class PatientPushPlanOfCareServiceAltCode(RedoxAbstractModel):

    Code: Union[str, None] = Field(None)
    CodeSystem: Union[str, None] = Field(None)
    CodeSystemName: Union[str, None] = Field(None)
    Name: Union[str, None] = Field(None)


class PatientPushPlanOfCareSupply(RedoxAbstractModel):

    AltCodes: List["PatientPushPlanOfCareSupplyAltCode"] = Field(None)
    Code: Union[str, None] = Field(None)
    CodeSystem: Union[str, None] = Field(None)
    CodeSystemName: Union[str, None] = Field(None)
    DateTime: Union[str, None] = Field(None)
    Name: Union[str, None] = Field(None)
    Status: Union[str, None] = Field(None)


class PatientPushPlanOfCareSupplyAltCode(RedoxAbstractModel):

    Code: Union[str, None] = Field(None)
    CodeSystem: Union[str, None] = Field(None)
    CodeSystemName: Union[str, None] = Field(None)
    Name: Union[str, None] = Field(None)


class PatientPushProblem(RedoxAbstractModel):

    AltCodes: List["PatientPushProblemAltCode"] = Field(None)
    Category: "PatientPushProblemCategory" = Field(None)
    Code: Union[str, None] = Field(None)
    CodeSystem: Union[str, None] = Field(None)
    CodeSystemName: Union[str, None] = Field(None)
    Comment: Union[str, None] = Field(None)
    EndDate: Union[str, None] = Field(None)
    HealthStatus: "PatientPushProblemHealthStatus" = Field(None)
    Name: Union[str, None] = Field(None)
    StartDate: Union[str, None] = Field(None)
    Status: "PatientPushProblemStatus" = Field(None)


class PatientPushProblemAltCode(RedoxAbstractModel):

    Code: Union[str, None] = Field(None)
    CodeSystem: Union[str, None] = Field(None)
    CodeSystemName: Union[str, None] = Field(None)
    Name: Union[str, None] = Field(None)


class PatientPushProblemCategory(RedoxAbstractModel):

    AltCodes: List["PatientPushProblemCategoryAltCode"] = Field(None)
    Code: Union[str, None] = Field(None)
    CodeSystem: Union[str, None] = Field(None)
    CodeSystemName: Union[str, None] = Field(None)
    Name: Union[str, None] = Field(None)


class PatientPushProblemCategoryAltCode(RedoxAbstractModel):

    Code: Union[str, None] = Field(None)
    CodeSystem: Union[str, None] = Field(None)
    CodeSystemName: Union[str, None] = Field(None)
    Name: Union[str, None] = Field(None)


class PatientPushProblemHealthStatus(RedoxAbstractModel):

    AltCodes: List["PatientPushProblemHealthStatusAltCode"] = Field(None)
    Code: Union[str, None] = Field(None)
    CodeSystem: Union[str, None] = Field(None)
    CodeSystemName: Union[str, None] = Field(None)
    Name: Union[str, None] = Field(None)


class PatientPushProblemHealthStatusAltCode(RedoxAbstractModel):

    Code: Union[str, None] = Field(None)
    CodeSystem: Union[str, None] = Field(None)
    CodeSystemName: Union[str, None] = Field(None)
    Name: Union[str, None] = Field(None)


class PatientPushProblemStatus(RedoxAbstractModel):

    Code: Union[str, None] = Field(None)
    CodeSystem: Union[str, None] = Field(None)
    CodeSystemName: Union[str, None] = Field(None)
    Name: Union[str, None] = Field(None)


class PatientPushProcedures(RedoxAbstractModel):

    Observations: List["PatientPushProceduresObservation"] = Field(None)
    Procedures: List["PatientPushProceduresProcedure"] = Field(None)
    Services: List["PatientPushProceduresService"] = Field(None)


class PatientPushProceduresObservation(RedoxAbstractModel):

    AltCodes: List["PatientPushProceduresObservationAltCode"] = Field(None)
    Code: Union[str, None] = Field(None)
    CodeSystem: Union[str, None] = Field(None)
    CodeSystemName: Union[str, None] = Field(None)
    DateTime: Union[str, None] = Field(None)
    Name: Union[str, None] = Field(None)
    Status: Union[str, None] = Field(None)
    TargetSite: "PatientPushProceduresObservationTargetSite" = Field(None)


class PatientPushProceduresObservationAltCode(RedoxAbstractModel):

    Code: Union[str, None] = Field(None)
    CodeSystem: Union[str, None] = Field(None)
    CodeSystemName: Union[str, None] = Field(None)
    Name: Union[str, None] = Field(None)


class PatientPushProceduresObservationTargetSite(RedoxAbstractModel):

    AltCodes: List["PatientPushProceduresObservationTargetSiteAltCode"] = Field(None)
    Code: Union[str, None] = Field(None)
    CodeSystem: Union[str, None] = Field(None)
    CodeSystemName: Union[str, None] = Field(None)
    Name: Union[str, None] = Field(None)


class PatientPushProceduresObservationTargetSiteAltCode(RedoxAbstractModel):

    Code: Union[str, None] = Field(None)
    CodeSystem: Union[str, None] = Field(None)
    CodeSystemName: Union[str, None] = Field(None)
    Name: Union[str, None] = Field(None)


class PatientPushProceduresProcedure(RedoxAbstractModel):

    AltCodes: List["PatientPushProceduresProcedureAltCode"] = Field(None)
    Code: Union[str, None] = Field(None)
    CodeSystem: Union[str, None] = Field(None)
    CodeSystemName: Union[str, None] = Field(None)
    DateTime: Union[str, None] = Field(None)
    Name: Union[str, None] = Field(None)
    Status: Union[str, None] = Field(None)
    TargetSite: "PatientPushProceduresProcedureTargetSite" = Field(None)


class PatientPushProceduresProcedureAltCode(RedoxAbstractModel):

    Code: Union[str, None] = Field(None)
    CodeSystem: Union[str, None] = Field(None)
    CodeSystemName: Union[str, None] = Field(None)
    Name: Union[str, None] = Field(None)


class PatientPushProceduresProcedureTargetSite(RedoxAbstractModel):

    AltCodes: List["PatientPushProceduresProcedureTargetSiteAltCode"] = Field(None)
    Code: Union[str, None] = Field(None)
    CodeSystem: Union[str, None] = Field(None)
    CodeSystemName: Union[str, None] = Field(None)
    Name: Union[str, None] = Field(None)


class PatientPushProceduresProcedureTargetSiteAltCode(RedoxAbstractModel):

    Code: Union[str, None] = Field(None)
    CodeSystem: Union[str, None] = Field(None)
    CodeSystemName: Union[str, None] = Field(None)
    Name: Union[str, None] = Field(None)


class PatientPushProceduresService(RedoxAbstractModel):

    AltCodes: List["PatientPushProceduresServiceAltCode"] = Field(None)
    Code: Union[str, None] = Field(None)
    CodeSystem: Union[str, None] = Field(None)
    CodeSystemName: Union[str, None] = Field(None)
    DateTime: Union[str, None] = Field(None)
    Name: Union[str, None] = Field(None)
    Status: Union[str, None] = Field(None)


class PatientPushProceduresServiceAltCode(RedoxAbstractModel):

    Code: Union[str, None] = Field(None)
    CodeSystem: Union[str, None] = Field(None)
    CodeSystemName: Union[str, None] = Field(None)
    Name: Union[str, None] = Field(None)


class PatientPushResolvedProblem(RedoxAbstractModel):

    AltCodes: List["PatientPushResolvedProblemAltCode"] = Field(None)
    Category: "PatientPushResolvedProblemCategory" = Field(None)
    Code: Union[str, None] = Field(None)
    CodeSystem: Union[str, None] = Field(None)
    CodeSystemName: Union[str, None] = Field(None)
    Comment: Union[str, None] = Field(None)
    EndDate: Union[str, None] = Field(None)
    Name: Union[str, None] = Field(None)
    StartDate: Union[str, None] = Field(None)
    Status: "PatientPushResolvedProblemStatus" = Field(None)


class PatientPushResolvedProblemAltCode(RedoxAbstractModel):

    Code: Union[str, None] = Field(None)
    CodeSystem: Union[str, None] = Field(None)
    CodeSystemName: Union[str, None] = Field(None)
    Name: Union[str, None] = Field(None)


class PatientPushResolvedProblemCategory(RedoxAbstractModel):

    AltCodes: List["PatientPushResolvedProblemCategoryAltCode"] = Field(None)
    Code: Union[str, None] = Field(None)
    CodeSystem: Union[str, None] = Field(None)
    CodeSystemName: Union[str, None] = Field(None)
    Name: Union[str, None] = Field(None)


class PatientPushResolvedProblemCategoryAltCode(RedoxAbstractModel):

    Code: Union[str, None] = Field(None)
    CodeSystem: Union[str, None] = Field(None)
    CodeSystemName: Union[str, None] = Field(None)
    Name: Union[str, None] = Field(None)


class PatientPushResolvedProblemStatus(RedoxAbstractModel):

    Code: Union[str, None] = Field(None)
    CodeSystem: Union[str, None] = Field(None)
    CodeSystemName: Union[str, None] = Field(None)
    Name: Union[str, None] = Field(None)


class PatientPushResult(RedoxAbstractModel):

    AltCodes: List["PatientPushResultAltCode"] = Field(None)
    Code: Union[str, None] = Field(None)
    CodeSystem: Union[str, None] = Field(None)
    CodeSystemName: Union[str, None] = Field(None)
    Name: Union[str, None] = Field(None)
    Observations: List["PatientPushResultObservation"] = Field(None)
    Producer: "PatientPushResultProducer" = Field(None)
    Status: Union[str, None] = Field(None)


class PatientPushResultAltCode(RedoxAbstractModel):

    Code: Union[str, None] = Field(None)
    CodeSystem: Union[str, None] = Field(None)
    CodeSystemName: Union[str, None] = Field(None)
    Name: Union[str, None] = Field(None)


class PatientPushResultObservation(RedoxAbstractModel):

    AltCodes: List["PatientPushResultObservationAltCode"] = Field(None)
    Code: Union[str, None] = Field(None)
    CodedValue: "PatientPushResultObservationCodedValue" = Field(None)
    CodeSystem: Union[str, None] = Field(None)
    CodeSystemName: Union[str, None] = Field(None)
    DateTime: Union[str, None] = Field(None)
    Interpretation: Union[str, None] = Field(None)
    Name: Union[str, None] = Field(None)
    ReferenceRange: "PatientPushResultObservationReferenceRange" = Field(None)
    Status: Union[str, None] = Field(None)
    Units: Union[str, None] = Field(None)
    Value: Union[str, None] = Field(None)
    ValueType: Union[str, None] = Field(None)


class PatientPushResultObservationAltCode(RedoxAbstractModel):

    Code: Union[str, None] = Field(None)
    CodeSystem: Union[str, None] = Field(None)
    CodeSystemName: Union[str, None] = Field(None)
    Name: Union[str, None] = Field(None)


class PatientPushResultObservationCodedValue(RedoxAbstractModel):

    AltCodes: List["PatientPushResultObservationCodedValueAltCode"] = Field(None)
    Code: Union[str, None] = Field(None)
    CodeSystem: Union[str, None] = Field(None)
    CodeSystemName: Union[str, None] = Field(None)
    Name: Union[str, None] = Field(None)


class PatientPushResultObservationCodedValueAltCode(RedoxAbstractModel):

    Code: Union[str, None] = Field(None)
    CodeSystem: Union[str, None] = Field(None)
    CodeSystemName: Union[str, None] = Field(None)
    Name: Union[str, None] = Field(None)


class PatientPushResultObservationReferenceRange(RedoxAbstractModel):

    High: Union[str, None] = Field(None)
    Low: Union[str, None] = Field(None)
    Text: Union[str, None] = Field(None)


class PatientPushResultProducer(RedoxAbstractModel):

    Address: "PatientPushResultProducerAddress" = Field(None)
    ID: Union[str, None] = Field(None)
    IDType: Union[str, None] = Field(None)
    Name: Union[str, None] = Field(None)


class PatientPushResultProducerAddress(RedoxAbstractModel):

    City: Union[str, None] = Field(None)
    Country: Union[str, None] = Field(None)
    County: Union[str, None] = Field(None)
    State: Union[str, None] = Field(None)
    StreetAddress: Union[str, None] = Field(None)
    ZIP: Union[str, None] = Field(None)


class PatientPushSocialHistory(RedoxAbstractModel):

    Observations: List["PatientPushSocialHistoryObservation"] = Field(None)
    Pregnancy: List["PatientPushSocialHistoryPregnancy"] = Field(None)
    TobaccoUse: List["PatientPushSocialHistoryTobaccoUse"] = Field(None)


class PatientPushSocialHistoryObservation(RedoxAbstractModel):

    AltCodes: List["PatientPushSocialHistoryObservationAltCode"] = Field(None)
    Code: Union[str, None] = Field(None)
    CodeSystem: Union[str, None] = Field(None)
    CodeSystemName: Union[str, None] = Field(None)
    EndDate: Union[str, None] = Field(None)
    Name: Union[str, None] = Field(None)
    StartDate: Union[str, None] = Field(None)
    Value: "PatientPushSocialHistoryObservationValue" = Field(None)
    ValueText: Union[str, None] = Field(None)


class PatientPushSocialHistoryObservationAltCode(RedoxAbstractModel):

    Code: Union[str, None] = Field(None)
    CodeSystem: Union[str, None] = Field(None)
    CodeSystemName: Union[str, None] = Field(None)
    Name: Union[str, None] = Field(None)


class PatientPushSocialHistoryObservationValue(RedoxAbstractModel):

    AltCodes: List["PatientPushSocialHistoryObservationValueAltCode"] = Field(None)
    Code: Union[str, None] = Field(None)
    CodeSystem: Union[str, None] = Field(None)
    CodeSystemName: Union[str, None] = Field(None)
    Name: Union[str, None] = Field(None)


class PatientPushSocialHistoryObservationValueAltCode(RedoxAbstractModel):

    Code: Union[str, None] = Field(None)
    CodeSystem: Union[str, None] = Field(None)
    CodeSystemName: Union[str, None] = Field(None)
    Name: Union[str, None] = Field(None)


class PatientPushSocialHistoryPregnancy(RedoxAbstractModel):

    EndDate: Union[str, None] = Field(None)
    EstimatedDelivery: Union[str, None] = Field(None)
    StartDate: Union[str, None] = Field(None)


class PatientPushSocialHistoryTobaccoUse(RedoxAbstractModel):

    AltCodes: List["PatientPushSocialHistoryTobaccoUseAltCode"] = Field(None)
    Code: Union[str, None] = Field(None)
    CodeSystem: Union[str, None] = Field(None)
    CodeSystemName: Union[str, None] = Field(None)
    EndDate: Union[str, None] = Field(None)
    IsSmokingStatus: Union[bool, None] = Field(None)
    Name: Union[str, None] = Field(None)
    StartDate: Union[str, None] = Field(None)


class PatientPushSocialHistoryTobaccoUseAltCode(RedoxAbstractModel):

    Code: Union[str, None] = Field(None)
    CodeSystem: Union[str, None] = Field(None)
    CodeSystemName: Union[str, None] = Field(None)
    Name: Union[str, None] = Field(None)


class PatientPushVitalSign(RedoxAbstractModel):

    DateTime: Union[str, None] = Field(None)
    Observations: List["PatientPushVitalSignObservation"] = Field(None)


class PatientPushVitalSignObservation(RedoxAbstractModel):

    AltCodes: List["PatientPushVitalSignObservationAltCode"] = Field(None)
    Code: Union[str, None] = Field(None)
    CodeSystem: Union[str, None] = Field(None)
    CodeSystemName: Union[str, None] = Field(None)
    DateTime: Union[str, None] = Field(None)
    Interpretation: Union[str, None] = Field(None)
    Name: Union[str, None] = Field(None)
    Status: Union[str, None] = Field(None)
    Units: Union[str, None] = Field(None)
    Value: Union[str, None] = Field(None)


class PatientPushVitalSignObservationAltCode(RedoxAbstractModel):

    Code: Union[str, None] = Field(None)
    CodeSystem: Union[str, None] = Field(None)
    CodeSystemName: Union[str, None] = Field(None)
    Name: Union[str, None] = Field(None)


PatientPush.update_forward_refs()
PatientPushAdvanceDirective.update_forward_refs()
PatientPushAdvanceDirectiveCustodian.update_forward_refs()
PatientPushAdvanceDirectiveType.update_forward_refs()
PatientPushAllergy.update_forward_refs()
PatientPushAllergyReaction.update_forward_refs()
PatientPushAllergySubstance.update_forward_refs()
PatientPushAllergyType.update_forward_refs()
PatientPushEncounter.update_forward_refs()
PatientPushEncounterDiagnosis.update_forward_refs()
PatientPushEncounterLocation.update_forward_refs()
PatientPushEncounterLocationType.update_forward_refs()
PatientPushEncounterProvider.update_forward_refs()
PatientPushEncounterProviderRole.update_forward_refs()
PatientPushEncounterReasonForVisit.update_forward_refs()
PatientPushEncounterType.update_forward_refs()
PatientPushFamilyHistory.update_forward_refs()
PatientPushFamilyHistoryProblem.update_forward_refs()
PatientPushFamilyHistoryRelation.update_forward_refs()
PatientPushFunctionalStatus.update_forward_refs()
PatientPushFunctionalStatusObservation.update_forward_refs()
PatientPushFunctionalStatusObservationCodedValue.update_forward_refs()
PatientPushFunctionalStatusSupply.update_forward_refs()
PatientPushGoal.update_forward_refs()
PatientPushGoalCodedValue.update_forward_refs()
PatientPushGoalMilestone.update_forward_refs()
PatientPushGoalMilestoneCodedValue.update_forward_refs()
PatientPushHeader.update_forward_refs()
PatientPushHeaderDocument.update_forward_refs()
PatientPushHeaderDocumentAuthor.update_forward_refs()
PatientPushHeaderDocumentCustodian.update_forward_refs()
PatientPushHeaderDocumentCustodianType.update_forward_refs()
PatientPushHeaderDocumentVisit.update_forward_refs()
PatientPushHeaderDocumentVisitType.update_forward_refs()
PatientPushHeaderPatient.update_forward_refs()
PatientPushHeaderPatientDemographics.update_forward_refs()
PatientPushHeaderPatientOrganization.update_forward_refs()
PatientPushHeaderPatientOrganizationType.update_forward_refs()
PatientPushHeaderPCP.update_forward_refs()
PatientPushHealthConcern.update_forward_refs()
PatientPushImmunization.update_forward_refs()
PatientPushImmunizationProduct.update_forward_refs()
PatientPushImmunizationRoute.update_forward_refs()
PatientPushInsurance.update_forward_refs()
PatientPushInsuranceCompany.update_forward_refs()
PatientPushInsuranceInsured.update_forward_refs()
PatientPushMedicalEquipment.update_forward_refs()
PatientPushMedicalEquipmentProduct.update_forward_refs()
PatientPushMedication.update_forward_refs()
PatientPushMedicationIndication.update_forward_refs()
PatientPushMedicationProduct.update_forward_refs()
PatientPushMedicationRoute.update_forward_refs()
PatientPushMeta.update_forward_refs()
PatientPushNoteSection.update_forward_refs()
PatientPushNoteSectionNote.update_forward_refs()
PatientPushNoteSectionNoteEncounter.update_forward_refs()
PatientPushNoteSectionNoteEncounterType.update_forward_refs()
PatientPushPlanOfCare.update_forward_refs()
PatientPushPlanOfCareEncounter.update_forward_refs()
PatientPushPlanOfCareMedicationAdministration.update_forward_refs()
PatientPushPlanOfCareMedicationAdministrationProduct.update_forward_refs()
PatientPushPlanOfCareMedicationAdministrationRoute.update_forward_refs()
PatientPushPlanOfCareOrder.update_forward_refs()
PatientPushPlanOfCareProcedure.update_forward_refs()
PatientPushPlanOfCareService.update_forward_refs()
PatientPushPlanOfCareSupply.update_forward_refs()
PatientPushProblem.update_forward_refs()
PatientPushProblemCategory.update_forward_refs()
PatientPushProblemHealthStatus.update_forward_refs()
PatientPushProcedures.update_forward_refs()
PatientPushProceduresObservation.update_forward_refs()
PatientPushProceduresObservationTargetSite.update_forward_refs()
PatientPushProceduresProcedure.update_forward_refs()
PatientPushProceduresProcedureTargetSite.update_forward_refs()
PatientPushProceduresService.update_forward_refs()
PatientPushResolvedProblem.update_forward_refs()
PatientPushResolvedProblemCategory.update_forward_refs()
PatientPushResult.update_forward_refs()
PatientPushResultObservation.update_forward_refs()
PatientPushResultObservationCodedValue.update_forward_refs()
PatientPushResultProducer.update_forward_refs()
PatientPushSocialHistory.update_forward_refs()
PatientPushSocialHistoryObservation.update_forward_refs()
PatientPushSocialHistoryObservationValue.update_forward_refs()
PatientPushSocialHistoryTobaccoUse.update_forward_refs()
PatientPushVitalSign.update_forward_refs()
PatientPushVitalSignObservation.update_forward_refs()



# -*- coding: utf-8 -*-
# ----  AUTO-GENERATED BY redox_lib_gen. DO NOT MODIFY MANUALLY!!  ---- #

from typing import List, Union

from pydantic import Field

from ..abstract_base import EventTypeAbstractModel, RedoxAbstractModel
from ..field_types import Number


class Replace(EventTypeAbstractModel):

    Meta: "ReplaceMeta" = Field(...)
    Note: "ReplaceNote" = Field(...)
    Orders: List["ReplaceOrder"] = Field(None)
    Patient: "ReplacePatient" = Field(...)
    Visit: "ReplaceVisit" = Field(None)


class ReplaceMeta(RedoxAbstractModel):

    DataModel: str = Field(...)
    Destinations: List["ReplaceMetaDestination"] = Field(None)
    EventDateTime: Union[str, None] = Field(None)
    EventType: str = Field(...)
    FacilityCode: Union[str, None] = Field(None)
    Logs: List["ReplaceMetaLog"] = Field(None)
    Message: "ReplaceMetaMessage" = Field(None)
    Source: "ReplaceMetaSource" = Field(None)
    Test: Union[bool, None] = Field(None)
    Transmission: "ReplaceMetaTransmission" = Field(None)


class ReplaceMetaDestination(RedoxAbstractModel):

    ID: Union[str, None] = Field(None)
    Name: Union[str, None] = Field(None)


class ReplaceMetaLog(RedoxAbstractModel):

    AttemptID: Union[str, None] = Field(None)
    ID: Union[str, None] = Field(None)


class ReplaceMetaMessage(RedoxAbstractModel):

    ID: Union[Number, None] = Field(None)


class ReplaceMetaSource(RedoxAbstractModel):

    ID: Union[str, None] = Field(None)
    Name: Union[str, None] = Field(None)


class ReplaceMetaTransmission(RedoxAbstractModel):

    ID: Union[Number, None] = Field(None)


class ReplaceNote(RedoxAbstractModel):

    Authenticator: "ReplaceNoteAuthenticator" = Field(None)
    Availability: Union[str, None] = Field(None)
    Components: List["ReplaceNoteComponent"] = Field(None)
    ContentType: str = Field(...)
    DocumentationDateTime: Union[str, None] = Field(None)
    DocumentDescription: Union[str, None] = Field(None)
    DocumentID: str = Field(...)
    DocumentType: str = Field(...)
    FileContents: Union[str, None] = Field(None)
    FileName: Union[str, None] = Field(None)
    FileType: Union[str, None] = Field(None)
    Notifications: List["ReplaceNoteNotification"] = Field(None)
    OriginalDocumentID: str = Field(...)
    Provider: "ReplaceNoteProvider" = Field(...)
    ServiceDateTime: Union[str, None] = Field(None)
    Status: Union[str, None] = Field(None)


class ReplaceNoteAuthenticator(RedoxAbstractModel):

    Address: "ReplaceNoteAuthenticatorAddress" = Field(None)
    Credentials: List[str] = Field(None)
    EmailAddresses: List[str] = Field(None)
    FirstName: Union[str, None] = Field(None)
    ID: Union[str, None] = Field(None)
    IDType: Union[str, None] = Field(None)
    LastName: Union[str, None] = Field(None)
    Location: "ReplaceNoteAuthenticatorLocation" = Field(None)
    PhoneNumber: "ReplaceNoteAuthenticatorPhoneNumber" = Field(None)


class ReplaceNoteAuthenticatorAddress(RedoxAbstractModel):

    City: Union[str, None] = Field(None)
    Country: Union[str, None] = Field(None)
    County: Union[str, None] = Field(None)
    State: Union[str, None] = Field(None)
    StreetAddress: Union[str, None] = Field(None)
    ZIP: Union[str, None] = Field(None)


class ReplaceNoteAuthenticatorLocation(RedoxAbstractModel):

    Department: Union[str, None] = Field(None)
    Facility: Union[str, None] = Field(None)
    Room: Union[str, None] = Field(None)
    Type: Union[str, None] = Field(None)


class ReplaceNoteAuthenticatorPhoneNumber(RedoxAbstractModel):

    Office: Union[str, None] = Field(None)


class ReplaceNoteComponent(RedoxAbstractModel):

    Comments: Union[str, None] = Field(None)
    ID: Union[str, None] = Field(None)
    Name: Union[str, None] = Field(None)
    Value: Union[str, None] = Field(None)


class ReplaceNoteNotification(RedoxAbstractModel):

    Address: "ReplaceNoteNotificationAddress" = Field(None)
    Credentials: List[str] = Field(None)
    EmailAddresses: List[str] = Field(None)
    FirstName: Union[str, None] = Field(None)
    ID: Union[str, None] = Field(None)
    IDType: Union[str, None] = Field(None)
    LastName: Union[str, None] = Field(None)
    Location: "ReplaceNoteNotificationLocation" = Field(None)
    PhoneNumber: "ReplaceNoteNotificationPhoneNumber" = Field(None)


class ReplaceNoteNotificationAddress(RedoxAbstractModel):

    City: Union[str, None] = Field(None)
    Country: Union[str, None] = Field(None)
    County: Union[str, None] = Field(None)
    State: Union[str, None] = Field(None)
    StreetAddress: Union[str, None] = Field(None)
    ZIP: Union[str, None] = Field(None)


class ReplaceNoteNotificationLocation(RedoxAbstractModel):

    Department: Union[str, None] = Field(None)
    Facility: Union[str, None] = Field(None)
    Room: Union[str, None] = Field(None)
    Type: Union[str, None] = Field(None)


class ReplaceNoteNotificationPhoneNumber(RedoxAbstractModel):

    Office: Union[str, None] = Field(None)


class ReplaceNoteProvider(RedoxAbstractModel):

    Address: "ReplaceNoteProviderAddress" = Field(None)
    Credentials: List[str] = Field(None)
    EmailAddresses: List[str] = Field(None)
    FirstName: Union[str, None] = Field(None)
    ID: str = Field(...)
    IDType: Union[str, None] = Field(None)
    LastName: Union[str, None] = Field(None)
    Location: "ReplaceNoteProviderLocation" = Field(None)
    PhoneNumber: "ReplaceNoteProviderPhoneNumber" = Field(None)


class ReplaceNoteProviderAddress(RedoxAbstractModel):

    City: Union[str, None] = Field(None)
    Country: Union[str, None] = Field(None)
    County: Union[str, None] = Field(None)
    State: Union[str, None] = Field(None)
    StreetAddress: Union[str, None] = Field(None)
    ZIP: Union[str, None] = Field(None)


class ReplaceNoteProviderLocation(RedoxAbstractModel):

    Department: Union[str, None] = Field(None)
    Facility: Union[str, None] = Field(None)
    Room: Union[str, None] = Field(None)
    Type: Union[str, None] = Field(None)


class ReplaceNoteProviderPhoneNumber(RedoxAbstractModel):

    Office: Union[str, None] = Field(None)


class ReplaceOrder(RedoxAbstractModel):

    ID: Union[str, None] = Field(None)
    Name: Union[str, None] = Field(None)


class ReplacePatient(RedoxAbstractModel):

    Demographics: "ReplacePatientDemographics" = Field(None)
    Identifiers: List["ReplacePatientIdentifier"] = Field(...)
    Notes: List[str] = Field(None)


class ReplacePatientDemographics(RedoxAbstractModel):

    Address: "ReplacePatientDemographicsAddress" = Field(None)
    Citizenship: List[str] = Field(None)
    DeathDateTime: Union[str, None] = Field(None)
    DOB: Union[str, None] = Field(None)
    EmailAddresses: List[str] = Field(None)
    FirstName: Union[str, None] = Field(None)
    IsDeceased: Union[bool, None] = Field(None)
    IsHispanic: Union[bool, None] = Field(None)
    Language: Union[str, None] = Field(None)
    LastName: Union[str, None] = Field(None)
    MaritalStatus: Union[str, None] = Field(None)
    MiddleName: Union[str, None] = Field(None)
    PhoneNumber: "ReplacePatientDemographicsPhoneNumber" = Field(None)
    Race: Union[str, None] = Field(None)
    Religion: Union[str, None] = Field(None)
    Sex: Union[str, None] = Field(None)
    SSN: Union[str, None] = Field(None)


class ReplacePatientDemographicsAddress(RedoxAbstractModel):

    City: Union[str, None] = Field(None)
    Country: Union[str, None] = Field(None)
    County: Union[str, None] = Field(None)
    State: Union[str, None] = Field(None)
    StreetAddress: Union[str, None] = Field(None)
    ZIP: Union[str, None] = Field(None)


class ReplacePatientDemographicsPhoneNumber(RedoxAbstractModel):

    Home: Union[str, None] = Field(None)
    Mobile: Union[str, None] = Field(None)
    Office: Union[str, None] = Field(None)


class ReplacePatientIdentifier(RedoxAbstractModel):

    ID: str = Field(...)
    IDType: str = Field(...)


class ReplaceVisit(RedoxAbstractModel):

    AccountNumber: Union[str, None] = Field(None)
    AdditionalStaff: List["ReplaceVisitAdditionalStaff"] = Field(None)
    Location: "ReplaceVisitLocation" = Field(None)
    PatientClass: Union[str, None] = Field(None)
    VisitDateTime: Union[str, None] = Field(None)
    VisitNumber: Union[str, None] = Field(None)


class ReplaceVisitAdditionalStaff(RedoxAbstractModel):

    Address: "ReplaceVisitAdditionalStaffAddress" = Field(None)
    Credentials: List[str] = Field(None)
    EmailAddresses: List[str] = Field(None)
    FirstName: Union[str, None] = Field(None)
    ID: Union[str, None] = Field(None)
    IDType: Union[str, None] = Field(None)
    LastName: Union[str, None] = Field(None)
    Location: "ReplaceVisitAdditionalStaffLocation" = Field(None)
    PhoneNumber: "ReplaceVisitAdditionalStaffPhoneNumber" = Field(None)
    Role: "ReplaceVisitAdditionalStaffRole" = Field(None)


class ReplaceVisitAdditionalStaffAddress(RedoxAbstractModel):

    City: Union[str, None] = Field(None)
    Country: Union[str, None] = Field(None)
    County: Union[str, None] = Field(None)
    State: Union[str, None] = Field(None)
    StreetAddress: Union[str, None] = Field(None)
    ZIP: Union[str, None] = Field(None)


class ReplaceVisitAdditionalStaffLocation(RedoxAbstractModel):

    Department: Union[str, None] = Field(None)
    Facility: Union[str, None] = Field(None)
    Room: Union[str, None] = Field(None)
    Type: Union[str, None] = Field(None)


class ReplaceVisitAdditionalStaffPhoneNumber(RedoxAbstractModel):

    Office: Union[str, None] = Field(None)


class ReplaceVisitAdditionalStaffRole(RedoxAbstractModel):

    Code: Union[str, None] = Field(None)
    Codeset: Union[str, None] = Field(None)
    Description: Union[str, None] = Field(None)


class ReplaceVisitLocation(RedoxAbstractModel):

    Bed: Union[str, None] = Field(None)
    Department: Union[str, None] = Field(None)
    Facility: Union[str, None] = Field(None)
    Room: Union[str, None] = Field(None)
    Type: Union[str, None] = Field(None)


Replace.update_forward_refs()
ReplaceMeta.update_forward_refs()
ReplaceNote.update_forward_refs()
ReplaceNoteAuthenticator.update_forward_refs()
ReplaceNoteNotification.update_forward_refs()
ReplaceNoteProvider.update_forward_refs()
ReplacePatient.update_forward_refs()
ReplacePatientDemographics.update_forward_refs()
ReplaceVisit.update_forward_refs()
ReplaceVisitAdditionalStaff.update_forward_refs()



# -*- coding: utf-8 -*-
# ----  AUTO-GENERATED BY redox_lib_gen. DO NOT MODIFY MANUALLY!!  ---- #

from typing import List, Union

from pydantic import Field

from pyredox import order
from ..abstract_base import GenericRedoxAbstractModel
from . import types as generic


class _Order(GenericRedoxAbstractModel):
    _redox_module = order


class Cancel(_Order):

    Meta: generic.Meta = Field(...)
    Order: generic.Order = Field(...)
    Patient: generic.Patient = Field(...)
    Visit: generic.Visit = Field(None)


class GroupedOrders(_Order):

    Meta: generic.Meta = Field(...)
    Orders: List[generic.Order] = Field(...)
    Patient: generic.Patient = Field(...)
    Visit: generic.Visit = Field(None)


class New(_Order):

    Meta: generic.Meta = Field(...)
    Order: generic.Order = Field(...)
    Patient: generic.Patient = Field(...)
    Visit: generic.Visit = Field(None)


class Query(_Order):

    EndDateTime: Union[str, None] = Field(None)
    Meta: generic.Meta = Field(...)
    OrderIDs: List[str] = Field(None)
    Patients: List[generic.Patient] = Field(None)
    Procedures: List[generic.Procedure] = Field(None)
    StartDateTime: Union[str, None] = Field(None)
    VisitNumbers: List[str] = Field(None)


class QueryResponse(_Order):

    Meta: generic.Meta = Field(...)
    Orders: List[generic.Order] = Field(None)


class Update(_Order):

    Meta: generic.Meta = Field(...)
    Order: generic.Order = Field(...)
    Patient: generic.Patient = Field(...)
    Visit: generic.Visit = Field(None)



# -*- coding: utf-8 -*-
# ----  AUTO-GENERATED BY redox_lib_gen. DO NOT MODIFY MANUALLY!!  ---- #

from typing import List, Union

from pydantic import Field

from ..abstract_base import EventTypeAbstractModel, RedoxAbstractModel
from ..field_types import Number


class Registration(EventTypeAbstractModel):

    Meta: "RegistrationMeta" = Field(...)
    Patient: "RegistrationPatient" = Field(...)
    Visit: "RegistrationVisit" = Field(None)


class RegistrationMeta(RedoxAbstractModel):

    DataModel: str = Field(...)
    Destinations: List["RegistrationMetaDestination"] = Field(None)
    EventDateTime: Union[str, None] = Field(None)
    EventType: str = Field(...)
    FacilityCode: Union[str, None] = Field(None)
    Logs: List["RegistrationMetaLog"] = Field(None)
    Message: "RegistrationMetaMessage" = Field(None)
    Source: "RegistrationMetaSource" = Field(None)
    Test: Union[bool, None] = Field(None)
    Transmission: "RegistrationMetaTransmission" = Field(None)


class RegistrationMetaDestination(RedoxAbstractModel):

    ID: Union[str, None] = Field(None)
    Name: Union[str, None] = Field(None)


class RegistrationMetaLog(RedoxAbstractModel):

    AttemptID: Union[str, None] = Field(None)
    ID: Union[str, None] = Field(None)


class RegistrationMetaMessage(RedoxAbstractModel):

    ID: Union[Number, None] = Field(None)


class RegistrationMetaSource(RedoxAbstractModel):

    ID: Union[str, None] = Field(None)
    Name: Union[str, None] = Field(None)


class RegistrationMetaTransmission(RedoxAbstractModel):

    ID: Union[Number, None] = Field(None)


class RegistrationPatient(RedoxAbstractModel):

    Allergies: List["RegistrationPatientAllergy"] = Field(None)
    Contacts: List["RegistrationPatientContact"] = Field(None)
    Demographics: "RegistrationPatientDemographics" = Field(None)
    Diagnoses: List["RegistrationPatientDiagnosis"] = Field(None)
    Identifiers: List["RegistrationPatientIdentifier"] = Field(...)
    Notes: List[str] = Field(None)
    PCP: "RegistrationPatientPCP" = Field(None)


class RegistrationPatientAllergy(RedoxAbstractModel):

    Code: Union[str, None] = Field(None)
    Codeset: Union[str, None] = Field(None)
    Name: Union[str, None] = Field(None)
    OnsetDateTime: Union[str, None] = Field(None)
    Reaction: List["RegistrationPatientAllergyReaction"] = Field(None)
    Severity: "RegistrationPatientAllergySeverity" = Field(None)
    Status: Union[str, None] = Field(None)
    Type: "RegistrationPatientAllergyType" = Field(None)


class RegistrationPatientAllergyReaction(RedoxAbstractModel):

    Code: Union[str, None] = Field(None)
    Codeset: Union[str, None] = Field(None)
    Name: Union[str, None] = Field(None)


class RegistrationPatientAllergySeverity(RedoxAbstractModel):

    Code: Union[str, None] = Field(None)
    Codeset: Union[str, None] = Field(None)
    Name: Union[str, None] = Field(None)


class RegistrationPatientAllergyType(RedoxAbstractModel):

    Code: Union[str, None] = Field(None)
    Codeset: Union[str, None] = Field(None)
    Name: Union[str, None] = Field(None)


class RegistrationPatientContact(RedoxAbstractModel):

    Address: "RegistrationPatientContactAddress" = Field(None)
    EmailAddresses: List[str] = Field(None)
    FirstName: Union[str, None] = Field(None)
    LastName: Union[str, None] = Field(None)
    MiddleName: Union[str, None] = Field(None)
    PhoneNumber: "RegistrationPatientContactPhoneNumber" = Field(None)
    RelationToPatient: Union[str, None] = Field(None)
    Roles: List[str] = Field(None)


class RegistrationPatientContactAddress(RedoxAbstractModel):

    City: Union[str, None] = Field(None)
    Country: Union[str, None] = Field(None)
    County: Union[str, None] = Field(None)
    State: Union[str, None] = Field(None)
    StreetAddress: Union[str, None] = Field(None)
    ZIP: Union[str, None] = Field(None)


class RegistrationPatientContactPhoneNumber(RedoxAbstractModel):

    Home: Union[str, None] = Field(None)
    Mobile: Union[str, None] = Field(None)
    Office: Union[str, None] = Field(None)


class RegistrationPatientDemographics(RedoxAbstractModel):

    Address: "RegistrationPatientDemographicsAddress" = Field(None)
    Citizenship: List[str] = Field(None)
    DeathDateTime: Union[str, None] = Field(None)
    DOB: Union[str, None] = Field(None)
    EmailAddresses: List[str] = Field(None)
    FirstName: Union[str, None] = Field(None)
    IsDeceased: Union[bool, None] = Field(None)
    IsHispanic: Union[bool, None] = Field(None)
    Language: Union[str, None] = Field(None)
    LastName: Union[str, None] = Field(None)
    MaritalStatus: Union[str, None] = Field(None)
    MiddleName: Union[str, None] = Field(None)
    PhoneNumber: "RegistrationPatientDemographicsPhoneNumber" = Field(None)
    Race: Union[str, None] = Field(None)
    Religion: Union[str, None] = Field(None)
    Sex: Union[str, None] = Field(None)
    SSN: Union[str, None] = Field(None)


class RegistrationPatientDemographicsAddress(RedoxAbstractModel):

    City: Union[str, None] = Field(None)
    Country: Union[str, None] = Field(None)
    County: Union[str, None] = Field(None)
    State: Union[str, None] = Field(None)
    StreetAddress: Union[str, None] = Field(None)
    ZIP: Union[str, None] = Field(None)


class RegistrationPatientDemographicsPhoneNumber(RedoxAbstractModel):

    Home: Union[str, None] = Field(None)
    Mobile: Union[str, None] = Field(None)
    Office: Union[str, None] = Field(None)


class RegistrationPatientDiagnosis(RedoxAbstractModel):

    Code: Union[str, None] = Field(None)
    Codeset: Union[str, None] = Field(None)
    DocumentedDateTime: Union[str, None] = Field(None)
    Name: Union[str, None] = Field(None)
    Type: Union[str, None] = Field(None)


class RegistrationPatientIdentifier(RedoxAbstractModel):

    ID: str = Field(...)
    IDType: str = Field(...)


class RegistrationPatientPCP(RedoxAbstractModel):

    Address: "RegistrationPatientPCPAddress" = Field(None)
    Credentials: List[str] = Field(None)
    EmailAddresses: List[str] = Field(None)
    FirstName: Union[str, None] = Field(None)
    ID: Union[str, None] = Field(None)
    IDType: Union[str, None] = Field(None)
    LastName: Union[str, None] = Field(None)
    Location: "RegistrationPatientPCPLocation" = Field(None)
    NPI: Union[str, None] = Field(None)
    PhoneNumber: "RegistrationPatientPCPPhoneNumber" = Field(None)


class RegistrationPatientPCPAddress(RedoxAbstractModel):

    City: Union[str, None] = Field(None)
    Country: Union[str, None] = Field(None)
    County: Union[str, None] = Field(None)
    State: Union[str, None] = Field(None)
    StreetAddress: Union[str, None] = Field(None)
    ZIP: Union[str, None] = Field(None)


class RegistrationPatientPCPLocation(RedoxAbstractModel):

    Department: Union[str, None] = Field(None)
    Facility: Union[str, None] = Field(None)
    Room: Union[str, None] = Field(None)
    Type: Union[str, None] = Field(None)


class RegistrationPatientPCPPhoneNumber(RedoxAbstractModel):

    Office: Union[str, None] = Field(None)


class RegistrationVisit(RedoxAbstractModel):

    AccountNumber: Union[str, None] = Field(None)
    AdditionalStaff: List["RegistrationVisitAdditionalStaff"] = Field(None)
    AdmittingProvider: "RegistrationVisitAdmittingProvider" = Field(None)
    AttendingProvider: "RegistrationVisitAttendingProvider" = Field(None)
    Balance: Union[Number, None] = Field(None)
    ConsultingProvider: "RegistrationVisitConsultingProvider" = Field(None)
    DiagnosisRelatedGroup: Union[Number, None] = Field(None)
    DiagnosisRelatedGroupType: Union[Number, None] = Field(None)
    Duration: Union[Number, None] = Field(None)
    Guarantor: "RegistrationVisitGuarantor" = Field(None)
    Instructions: List[str] = Field(None)
    Insurances: List["RegistrationVisitInsurance"] = Field(None)
    Location: "RegistrationVisitLocation" = Field(None)
    PatientClass: Union[str, None] = Field(None)
    Reason: Union[str, None] = Field(None)
    ReferringProvider: "RegistrationVisitReferringProvider" = Field(None)
    VisitDateTime: Union[str, None] = Field(None)
    VisitNumber: Union[str, None] = Field(None)


class RegistrationVisitAdditionalStaff(RedoxAbstractModel):

    Address: "RegistrationVisitAdditionalStaffAddress" = Field(None)
    Credentials: List[str] = Field(None)
    EmailAddresses: List[str] = Field(None)
    FirstName: Union[str, None] = Field(None)
    ID: Union[str, None] = Field(None)
    IDType: Union[str, None] = Field(None)
    LastName: Union[str, None] = Field(None)
    Location: "RegistrationVisitAdditionalStaffLocation" = Field(None)
    PhoneNumber: "RegistrationVisitAdditionalStaffPhoneNumber" = Field(None)
    Role: "RegistrationVisitAdditionalStaffRole" = Field(None)


class RegistrationVisitAdditionalStaffAddress(RedoxAbstractModel):

    City: Union[str, None] = Field(None)
    Country: Union[str, None] = Field(None)
    County: Union[str, None] = Field(None)
    State: Union[str, None] = Field(None)
    StreetAddress: Union[str, None] = Field(None)
    ZIP: Union[str, None] = Field(None)


class RegistrationVisitAdditionalStaffLocation(RedoxAbstractModel):

    Department: Union[str, None] = Field(None)
    Facility: Union[str, None] = Field(None)
    Room: Union[str, None] = Field(None)
    Type: Union[str, None] = Field(None)


class RegistrationVisitAdditionalStaffPhoneNumber(RedoxAbstractModel):

    Office: Union[str, None] = Field(None)


class RegistrationVisitAdditionalStaffRole(RedoxAbstractModel):

    Code: Union[str, None] = Field(None)
    Codeset: Union[str, None] = Field(None)
    Description: Union[str, None] = Field(None)


class RegistrationVisitAdmittingProvider(RedoxAbstractModel):

    Address: "RegistrationVisitAdmittingProviderAddress" = Field(None)
    Credentials: List[str] = Field(None)
    EmailAddresses: List[str] = Field(None)
    FirstName: Union[str, None] = Field(None)
    ID: Union[str, None] = Field(None)
    IDType: Union[str, None] = Field(None)
    LastName: Union[str, None] = Field(None)
    Location: "RegistrationVisitAdmittingProviderLocation" = Field(None)
    PhoneNumber: "RegistrationVisitAdmittingProviderPhoneNumber" = Field(None)


class RegistrationVisitAdmittingProviderAddress(RedoxAbstractModel):

    City: Union[str, None] = Field(None)
    Country: Union[str, None] = Field(None)
    County: Union[str, None] = Field(None)
    State: Union[str, None] = Field(None)
    StreetAddress: Union[str, None] = Field(None)
    ZIP: Union[str, None] = Field(None)


class RegistrationVisitAdmittingProviderLocation(RedoxAbstractModel):

    Department: Union[str, None] = Field(None)
    Facility: Union[str, None] = Field(None)
    Room: Union[str, None] = Field(None)
    Type: Union[str, None] = Field(None)


class RegistrationVisitAdmittingProviderPhoneNumber(RedoxAbstractModel):

    Office: Union[str, None] = Field(None)


class RegistrationVisitAttendingProvider(RedoxAbstractModel):

    Address: "RegistrationVisitAttendingProviderAddress" = Field(None)
    Credentials: List[str] = Field(None)
    EmailAddresses: List[str] = Field(None)
    FirstName: Union[str, None] = Field(None)
    ID: Union[str, None] = Field(None)
    IDType: Union[str, None] = Field(None)
    LastName: Union[str, None] = Field(None)
    Location: "RegistrationVisitAttendingProviderLocation" = Field(None)
    PhoneNumber: "RegistrationVisitAttendingProviderPhoneNumber" = Field(None)


class RegistrationVisitAttendingProviderAddress(RedoxAbstractModel):

    City: Union[str, None] = Field(None)
    Country: Union[str, None] = Field(None)
    County: Union[str, None] = Field(None)
    State: Union[str, None] = Field(None)
    StreetAddress: Union[str, None] = Field(None)
    ZIP: Union[str, None] = Field(None)


class RegistrationVisitAttendingProviderLocation(RedoxAbstractModel):

    Department: Union[str, None] = Field(None)
    Facility: Union[str, None] = Field(None)
    Room: Union[str, None] = Field(None)
    Type: Union[str, None] = Field(None)


class RegistrationVisitAttendingProviderPhoneNumber(RedoxAbstractModel):

    Office: Union[str, None] = Field(None)


class RegistrationVisitConsultingProvider(RedoxAbstractModel):

    Address: "RegistrationVisitConsultingProviderAddress" = Field(None)
    Credentials: List[str] = Field(None)
    EmailAddresses: List[str] = Field(None)
    FirstName: Union[str, None] = Field(None)
    ID: Union[str, None] = Field(None)
    IDType: Union[str, None] = Field(None)
    LastName: Union[str, None] = Field(None)
    Location: "RegistrationVisitConsultingProviderLocation" = Field(None)
    PhoneNumber: "RegistrationVisitConsultingProviderPhoneNumber" = Field(None)


class RegistrationVisitConsultingProviderAddress(RedoxAbstractModel):

    City: Union[str, None] = Field(None)
    Country: Union[str, None] = Field(None)
    County: Union[str, None] = Field(None)
    State: Union[str, None] = Field(None)
    StreetAddress: Union[str, None] = Field(None)
    ZIP: Union[str, None] = Field(None)


class RegistrationVisitConsultingProviderLocation(RedoxAbstractModel):

    Department: Union[str, None] = Field(None)
    Facility: Union[str, None] = Field(None)
    Room: Union[str, None] = Field(None)
    Type: Union[str, None] = Field(None)


class RegistrationVisitConsultingProviderPhoneNumber(RedoxAbstractModel):

    Office: Union[str, None] = Field(None)


class RegistrationVisitGuarantor(RedoxAbstractModel):

    Address: "RegistrationVisitGuarantorAddress" = Field(None)
    DOB: Union[str, None] = Field(None)
    EmailAddresses: List[str] = Field(None)
    Employer: "RegistrationVisitGuarantorEmployer" = Field(None)
    FirstName: Union[str, None] = Field(None)
    LastName: Union[str, None] = Field(None)
    MiddleName: Union[str, None] = Field(None)
    Number: Union[str, None] = Field(None)
    PhoneNumber: "RegistrationVisitGuarantorPhoneNumber" = Field(None)
    RelationToPatient: Union[str, None] = Field(None)
    Sex: Union[str, None] = Field(None)
    Spouse: "RegistrationVisitGuarantorSpouse" = Field(None)
    SSN: Union[str, None] = Field(None)
    Type: Union[str, None] = Field(None)


class RegistrationVisitGuarantorAddress(RedoxAbstractModel):

    City: Union[str, None] = Field(None)
    Country: Union[str, None] = Field(None)
    County: Union[str, None] = Field(None)
    State: Union[str, None] = Field(None)
    StreetAddress: Union[str, None] = Field(None)
    ZIP: Union[str, None] = Field(None)


class RegistrationVisitGuarantorEmployer(RedoxAbstractModel):

    Address: "RegistrationVisitGuarantorEmployerAddress" = Field(None)
    Name: Union[str, None] = Field(None)
    PhoneNumber: Union[str, None] = Field(None)


class RegistrationVisitGuarantorEmployerAddress(RedoxAbstractModel):

    City: Union[str, None] = Field(None)
    Country: Union[str, None] = Field(None)
    County: Union[str, None] = Field(None)
    State: Union[str, None] = Field(None)
    StreetAddress: Union[str, None] = Field(None)
    ZIP: Union[str, None] = Field(None)


class RegistrationVisitGuarantorPhoneNumber(RedoxAbstractModel):

    Business: Union[str, None] = Field(None)
    Home: Union[str, None] = Field(None)
    Mobile: Union[str, None] = Field(None)


class RegistrationVisitGuarantorSpouse(RedoxAbstractModel):

    FirstName: Union[str, None] = Field(None)
    LastName: Union[str, None] = Field(None)


class RegistrationVisitInsurance(RedoxAbstractModel):

    AgreementType: Union[str, None] = Field(None)
    Company: "RegistrationVisitInsuranceCompany" = Field(None)
    CoverageType: Union[str, None] = Field(None)
    EffectiveDate: Union[str, None] = Field(None)
    ExpirationDate: Union[str, None] = Field(None)
    GroupName: Union[str, None] = Field(None)
    GroupNumber: Union[str, None] = Field(None)
    Insured: "RegistrationVisitInsuranceInsured" = Field(None)
    MemberNumber: Union[str, None] = Field(None)
    Plan: "RegistrationVisitInsurancePlan" = Field(None)
    PolicyNumber: Union[str, None] = Field(None)
    Priority: Union[str, None] = Field(None)


class RegistrationVisitInsuranceCompany(RedoxAbstractModel):

    Address: "RegistrationVisitInsuranceCompanyAddress" = Field(None)
    ID: Union[str, None] = Field(None)
    IDType: Union[str, None] = Field(None)
    Name: Union[str, None] = Field(None)
    PhoneNumber: Union[str, None] = Field(None)


class RegistrationVisitInsuranceCompanyAddress(RedoxAbstractModel):

    City: Union[str, None] = Field(None)
    Country: Union[str, None] = Field(None)
    County: Union[str, None] = Field(None)
    State: Union[str, None] = Field(None)
    StreetAddress: Union[str, None] = Field(None)
    ZIP: Union[str, None] = Field(None)


class RegistrationVisitInsuranceInsured(RedoxAbstractModel):

    Address: "RegistrationVisitInsuranceInsuredAddress" = Field(None)
    DOB: Union[str, None] = Field(None)
    FirstName: Union[str, None] = Field(None)
    Identifiers: List["RegistrationVisitInsuranceInsuredIdentifier"] = Field(None)
    LastName: Union[str, None] = Field(None)
    MiddleName: Union[str, None] = Field(None)
    Relationship: Union[str, None] = Field(None)
    Sex: Union[str, None] = Field(None)
    SSN: Union[str, None] = Field(None)


class RegistrationVisitInsuranceInsuredAddress(RedoxAbstractModel):

    City: Union[str, None] = Field(None)
    Country: Union[str, None] = Field(None)
    County: Union[str, None] = Field(None)
    State: Union[str, None] = Field(None)
    StreetAddress: Union[str, None] = Field(None)
    ZIP: Union[str, None] = Field(None)


class RegistrationVisitInsuranceInsuredIdentifier(RedoxAbstractModel):

    ID: Union[str, None] = Field(None)
    IDType: Union[str, None] = Field(None)


class RegistrationVisitInsurancePlan(RedoxAbstractModel):

    ID: Union[str, None] = Field(None)
    IDType: Union[str, None] = Field(None)
    Name: Union[str, None] = Field(None)
    Type: Union[str, None] = Field(None)


class RegistrationVisitLocation(RedoxAbstractModel):

    Address: "RegistrationVisitLocationAddress" = Field(None)
    Bed: Union[str, None] = Field(None)
    Department: Union[str, None] = Field(None)
    Facility: Union[str, None] = Field(None)
    Room: Union[str, None] = Field(None)
    Type: Union[str, None] = Field(None)


class RegistrationVisitLocationAddress(RedoxAbstractModel):

    City: Union[str, None] = Field(None)
    Country: Union[str, None] = Field(None)
    County: Union[str, None] = Field(None)
    State: Union[str, None] = Field(None)
    StreetAddress: Union[str, None] = Field(None)
    ZIP: Union[str, None] = Field(None)


class RegistrationVisitReferringProvider(RedoxAbstractModel):

    Address: "RegistrationVisitReferringProviderAddress" = Field(None)
    Credentials: List[str] = Field(None)
    EmailAddresses: List[str] = Field(None)
    FirstName: Union[str, None] = Field(None)
    ID: Union[str, None] = Field(None)
    IDType: Union[str, None] = Field(None)
    LastName: Union[str, None] = Field(None)
    Location: "RegistrationVisitReferringProviderLocation" = Field(None)
    PhoneNumber: "RegistrationVisitReferringProviderPhoneNumber" = Field(None)


class RegistrationVisitReferringProviderAddress(RedoxAbstractModel):

    City: Union[str, None] = Field(None)
    Country: Union[str, None] = Field(None)
    County: Union[str, None] = Field(None)
    State: Union[str, None] = Field(None)
    StreetAddress: Union[str, None] = Field(None)
    ZIP: Union[str, None] = Field(None)


class RegistrationVisitReferringProviderLocation(RedoxAbstractModel):

    Department: Union[str, None] = Field(None)
    Facility: Union[str, None] = Field(None)
    Room: Union[str, None] = Field(None)
    Type: Union[str, None] = Field(None)


class RegistrationVisitReferringProviderPhoneNumber(RedoxAbstractModel):

    Office: Union[str, None] = Field(None)


Registration.update_forward_refs()
RegistrationMeta.update_forward_refs()
RegistrationPatient.update_forward_refs()
RegistrationPatientAllergy.update_forward_refs()
RegistrationPatientContact.update_forward_refs()
RegistrationPatientDemographics.update_forward_refs()
RegistrationPatientPCP.update_forward_refs()
RegistrationVisit.update_forward_refs()
RegistrationVisitAdditionalStaff.update_forward_refs()
RegistrationVisitAdmittingProvider.update_forward_refs()
RegistrationVisitAttendingProvider.update_forward_refs()
RegistrationVisitConsultingProvider.update_forward_refs()
RegistrationVisitGuarantor.update_forward_refs()
RegistrationVisitGuarantorEmployer.update_forward_refs()
RegistrationVisitInsurance.update_forward_refs()
RegistrationVisitInsuranceCompany.update_forward_refs()
RegistrationVisitInsuranceInsured.update_forward_refs()
RegistrationVisitLocation.update_forward_refs()
RegistrationVisitReferringProvider.update_forward_refs()



# -*- coding: utf-8 -*-
# ----  AUTO-GENERATED BY redox_lib_gen. DO NOT MODIFY MANUALLY!!  ---- #

from typing import List, Union

from pydantic import Field

from ..abstract_base import EventTypeAbstractModel, RedoxAbstractModel
from ..field_types import Number


class VisitQuery(EventTypeAbstractModel):

    Departments: List[str] = Field(None)
    Facilities: List[str] = Field(None)
    Meta: "VisitQueryMeta" = Field(...)
    PatientClasses: List[str] = Field(None)
    Patients: List["VisitQueryPatient"] = Field(None)
    VisitNumbers: List[str] = Field(None)
    VisitStartDateTime: Union[str, None] = Field(None)
    VisitStatuses: List[str] = Field(None)


class VisitQueryMeta(RedoxAbstractModel):

    DataModel: str = Field(...)
    Destinations: List["VisitQueryMetaDestination"] = Field(None)
    EventDateTime: Union[str, None] = Field(None)
    EventType: str = Field(...)
    FacilityCode: Union[str, None] = Field(None)
    Logs: List["VisitQueryMetaLog"] = Field(None)
    Message: "VisitQueryMetaMessage" = Field(None)
    Source: "VisitQueryMetaSource" = Field(None)
    Test: Union[bool, None] = Field(None)
    Transmission: "VisitQueryMetaTransmission" = Field(None)


class VisitQueryMetaDestination(RedoxAbstractModel):

    ID: Union[str, None] = Field(None)
    Name: Union[str, None] = Field(None)


class VisitQueryMetaLog(RedoxAbstractModel):

    AttemptID: Union[str, None] = Field(None)
    ID: Union[str, None] = Field(None)


class VisitQueryMetaMessage(RedoxAbstractModel):

    ID: Union[Number, None] = Field(None)


class VisitQueryMetaSource(RedoxAbstractModel):

    ID: Union[str, None] = Field(None)
    Name: Union[str, None] = Field(None)


class VisitQueryMetaTransmission(RedoxAbstractModel):

    ID: Union[Number, None] = Field(None)


class VisitQueryPatient(RedoxAbstractModel):

    Identifiers: List["VisitQueryPatientIdentifier"] = Field(None)


class VisitQueryPatientIdentifier(RedoxAbstractModel):

    ID: Union[str, None] = Field(None)
    IDType: Union[str, None] = Field(None)


VisitQuery.update_forward_refs()
VisitQueryMeta.update_forward_refs()
VisitQueryPatient.update_forward_refs()



# -*- coding: utf-8 -*-
# ----  AUTO-GENERATED BY redox_lib_gen. DO NOT MODIFY MANUALLY!!  ---- #

from typing import List, Union

from pydantic import Field

from ..abstract_base import EventTypeAbstractModel, RedoxAbstractModel
from ..field_types import Number


class Deplete(EventTypeAbstractModel):

    Items: List["DepleteItem"] = Field(...)
    Meta: "DepleteMeta" = Field(...)
    Patient: "DepletePatient" = Field(None)
    Visit: "DepleteVisit" = Field(None)


class DepleteItem(RedoxAbstractModel):

    Description: Union[str, None] = Field(None)
    Identifiers: List["DepleteItemIdentifier"] = Field(...)
    Location: "DepleteItemLocation" = Field(None)
    LotNumber: Union[str, None] = Field(None)
    Notes: Union[str, None] = Field(None)
    OrderingProvider: "DepleteItemOrderingProvider" = Field(None)
    Procedure: "DepleteItemProcedure" = Field(None)
    Quantity: Union[Number, None] = Field(None)
    SerialNumber: Union[str, None] = Field(None)
    Type: Union[str, None] = Field(None)
    Units: Union[str, None] = Field(None)
    UsedQuantity: Union[Number, None] = Field(None)
    Vendor: "DepleteItemVendor" = Field(None)
    WastedQuantity: Union[Number, None] = Field(None)


class DepleteItemIdentifier(RedoxAbstractModel):

    ID: str = Field(...)
    IDType: str = Field(...)


class DepleteItemLocation(RedoxAbstractModel):

    Bin: Union[str, None] = Field(None)
    Department: Union[str, None] = Field(None)
    Facility: Union[str, None] = Field(None)
    ID: Union[str, None] = Field(None)


class DepleteItemOrderingProvider(RedoxAbstractModel):

    Address: "DepleteItemOrderingProviderAddress" = Field(None)
    Credentials: List[str] = Field(None)
    EmailAddresses: List[str] = Field(None)
    FirstName: Union[str, None] = Field(None)
    ID: Union[str, None] = Field(None)
    IDType: Union[str, None] = Field(None)
    LastName: Union[str, None] = Field(None)
    Location: "DepleteItemOrderingProviderLocation" = Field(None)
    PhoneNumber: "DepleteItemOrderingProviderPhoneNumber" = Field(None)


class DepleteItemOrderingProviderAddress(RedoxAbstractModel):

    City: Union[str, None] = Field(None)
    Country: Union[str, None] = Field(None)
    County: Union[str, None] = Field(None)
    State: Union[str, None] = Field(None)
    StreetAddress: Union[str, None] = Field(None)
    ZIP: Union[str, None] = Field(None)


class DepleteItemOrderingProviderLocation(RedoxAbstractModel):

    Department: Union[str, None] = Field(None)
    Facility: Union[str, None] = Field(None)
    Room: Union[str, None] = Field(None)
    Type: Union[str, None] = Field(None)


class DepleteItemOrderingProviderPhoneNumber(RedoxAbstractModel):

    Office: Union[str, None] = Field(None)


class DepleteItemProcedure(RedoxAbstractModel):

    Code: Union[str, None] = Field(None)
    Codeset: Union[str, None] = Field(None)
    Modifier: Union[str, None] = Field(None)


class DepleteItemVendor(RedoxAbstractModel):

    CatalogNumber: Union[str, None] = Field(None)
    ID: Union[str, None] = Field(None)
    Name: Union[str, None] = Field(None)


class DepleteMeta(RedoxAbstractModel):

    DataModel: str = Field(...)
    Destinations: List["DepleteMetaDestination"] = Field(None)
    EventDateTime: Union[str, None] = Field(None)
    EventType: str = Field(...)
    FacilityCode: Union[str, None] = Field(None)
    Logs: List["DepleteMetaLog"] = Field(None)
    Message: "DepleteMetaMessage" = Field(None)
    Source: "DepleteMetaSource" = Field(None)
    Test: Union[bool, None] = Field(None)
    Transmission: "DepleteMetaTransmission" = Field(None)


class DepleteMetaDestination(RedoxAbstractModel):

    ID: Union[str, None] = Field(None)
    Name: Union[str, None] = Field(None)


class DepleteMetaLog(RedoxAbstractModel):

    AttemptID: Union[str, None] = Field(None)
    ID: Union[str, None] = Field(None)


class DepleteMetaMessage(RedoxAbstractModel):

    ID: Union[Number, None] = Field(None)


class DepleteMetaSource(RedoxAbstractModel):

    ID: Union[str, None] = Field(None)
    Name: Union[str, None] = Field(None)


class DepleteMetaTransmission(RedoxAbstractModel):

    ID: Union[Number, None] = Field(None)


class DepletePatient(RedoxAbstractModel):

    Demographics: "DepletePatientDemographics" = Field(None)
    Identifiers: List["DepletePatientIdentifier"] = Field(None)
    Notes: List[str] = Field(None)


class DepletePatientDemographics(RedoxAbstractModel):

    Address: "DepletePatientDemographicsAddress" = Field(None)
    Citizenship: List[str] = Field(None)
    DeathDateTime: Union[str, None] = Field(None)
    DOB: Union[str, None] = Field(None)
    EmailAddresses: List[str] = Field(None)
    FirstName: Union[str, None] = Field(None)
    IsDeceased: Union[bool, None] = Field(None)
    IsHispanic: Union[bool, None] = Field(None)
    Language: Union[str, None] = Field(None)
    LastName: Union[str, None] = Field(None)
    MaritalStatus: Union[str, None] = Field(None)
    MiddleName: Union[str, None] = Field(None)
    PhoneNumber: "DepletePatientDemographicsPhoneNumber" = Field(None)
    Race: Union[str, None] = Field(None)
    Religion: Union[str, None] = Field(None)
    Sex: Union[str, None] = Field(None)
    SSN: Union[str, None] = Field(None)


class DepletePatientDemographicsAddress(RedoxAbstractModel):

    City: Union[str, None] = Field(None)
    Country: Union[str, None] = Field(None)
    County: Union[str, None] = Field(None)
    State: Union[str, None] = Field(None)
    StreetAddress: Union[str, None] = Field(None)
    ZIP: Union[str, None] = Field(None)


class DepletePatientDemographicsPhoneNumber(RedoxAbstractModel):

    Home: Union[str, None] = Field(None)
    Mobile: Union[str, None] = Field(None)
    Office: Union[str, None] = Field(None)


class DepletePatientIdentifier(RedoxAbstractModel):

    ID: Union[str, None] = Field(None)
    IDType: Union[str, None] = Field(None)


class DepleteVisit(RedoxAbstractModel):

    VisitNumber: Union[str, None] = Field(None)


Deplete.update_forward_refs()
DepleteItem.update_forward_refs()
DepleteItemOrderingProvider.update_forward_refs()
DepleteMeta.update_forward_refs()
DepletePatient.update_forward_refs()
DepletePatientDemographics.update_forward_refs()



# -*- coding: utf-8 -*-
# flake8: noqa: F401
from .cancel import Cancel
from .groupedorders import GroupedOrders
from .new import New
from .query import Query
from .queryresponse import QueryResponse
from .update import Update



# -*- coding: utf-8 -*-
# ----  AUTO-GENERATED BY redox_lib_gen. DO NOT MODIFY MANUALLY!!  ---- #

from typing import List, Union

from pydantic import Field

from ..abstract_base import EventTypeAbstractModel, RedoxAbstractModel
from ..field_types import Number


class New(EventTypeAbstractModel):

    Directory: str = Field(...)
    Meta: "NewMeta" = Field(...)
    Organizations: List["NewOrganization"] = Field(...)


class NewMeta(RedoxAbstractModel):

    DataModel: str = Field(...)
    Destinations: List["NewMetaDestination"] = Field(None)
    EventDateTime: Union[str, None] = Field(None)
    EventType: str = Field(...)
    FacilityCode: Union[str, None] = Field(None)
    Logs: List["NewMetaLog"] = Field(None)
    Message: "NewMetaMessage" = Field(None)
    Source: "NewMetaSource" = Field(None)
    Test: Union[bool, None] = Field(None)
    Transmission: "NewMetaTransmission" = Field(None)


class NewMetaDestination(RedoxAbstractModel):

    ID: Union[str, None] = Field(None)
    Name: Union[str, None] = Field(None)


class NewMetaLog(RedoxAbstractModel):

    AttemptID: Union[str, None] = Field(None)
    ID: Union[str, None] = Field(None)


class NewMetaMessage(RedoxAbstractModel):

    ID: Union[Number, None] = Field(None)


class NewMetaSource(RedoxAbstractModel):

    ID: Union[str, None] = Field(None)
    Name: Union[str, None] = Field(None)


class NewMetaTransmission(RedoxAbstractModel):

    ID: Union[Number, None] = Field(None)


class NewOrganization(RedoxAbstractModel):

    Active: bool = Field(...)
    Address: "NewOrganizationAddress" = Field(None)
    Aliases: List[str] = Field(None)
    Contacts: List["NewOrganizationContact"] = Field(None)
    DestinationID: Union[str, None] = Field(None)
    Endpoints: List["NewOrganizationEndpoint"] = Field(None)
    Identifiers: List["NewOrganizationIdentifier"] = Field(None)
    Name: str = Field(...)
    PartOf: "NewOrganizationPartOf" = Field(None)
    Type: "NewOrganizationType" = Field(None)


class NewOrganizationAddress(RedoxAbstractModel):

    City: Union[str, None] = Field(None)
    Country: Union[str, None] = Field(None)
    County: Union[str, None] = Field(None)
    State: Union[str, None] = Field(None)
    StreetAddress: Union[str, None] = Field(None)
    ZIP: Union[str, None] = Field(None)


class NewOrganizationContact(RedoxAbstractModel):

    EmailAddresses: List[str] = Field(None)
    Name: Union[str, None] = Field(None)
    PhoneNumber: "NewOrganizationContactPhoneNumber" = Field(None)
    Purpose: Union[str, None] = Field(None)


class NewOrganizationContactPhoneNumber(RedoxAbstractModel):

    Home: Union[str, None] = Field(None)
    Mobile: Union[str, None] = Field(None)
    Work: Union[str, None] = Field(None)


class NewOrganizationEndpoint(RedoxAbstractModel):

    Address: Union[str, None] = Field(None)
    Attributes: "NewOrganizationEndpointAttributes" = Field(None)
    ConnectionType: "NewOrganizationEndpointConnectionType" = Field(None)
    Identifiers: List["NewOrganizationEndpointIdentifier"] = Field(None)
    MIMEType: Union[str, None] = Field(None)
    Name: Union[str, None] = Field(None)


class NewOrganizationEndpointAttributes(RedoxAbstractModel):

    Actor: "NewOrganizationEndpointAttributesActor" = Field(None)
    PurposeOfUse: List["NewOrganizationEndpointAttributesPurposeOfUse"] = Field(None)
    Roles: List["NewOrganizationEndpointAttributesRole"] = Field(None)
    Transaction: Union[str, None] = Field(None)
    UseCases: List["NewOrganizationEndpointAttributesUseCase"] = Field(None)
    Version: "NewOrganizationEndpointAttributesVersion" = Field(None)


class NewOrganizationEndpointAttributesActor(RedoxAbstractModel):

    System: Union[str, None] = Field(None)
    Value: Union[str, None] = Field(None)


class NewOrganizationEndpointAttributesPurposeOfUse(RedoxAbstractModel):

    System: Union[str, None] = Field(None)
    Value: Union[str, None] = Field(None)


class NewOrganizationEndpointAttributesRole(RedoxAbstractModel):

    System: Union[str, None] = Field(None)
    Value: Union[str, None] = Field(None)


class NewOrganizationEndpointAttributesUseCase(RedoxAbstractModel):

    System: Union[str, None] = Field(None)
    Value: Union[str, None] = Field(None)


class NewOrganizationEndpointAttributesVersion(RedoxAbstractModel):

    System: Union[str, None] = Field(None)
    Value: Union[str, None] = Field(None)


class NewOrganizationEndpointConnectionType(RedoxAbstractModel):

    System: Union[str, None] = Field(None)
    Value: Union[str, None] = Field(None)


class NewOrganizationEndpointIdentifier(RedoxAbstractModel):

    System: Union[str, None] = Field(None)
    Type: Union[str, None] = Field(None)
    Value: Union[str, None] = Field(None)


class NewOrganizationIdentifier(RedoxAbstractModel):

    ID: Union[str, None] = Field(None)
    IDType: Union[str, None] = Field(None)


class NewOrganizationPartOf(RedoxAbstractModel):

    Identifier: "NewOrganizationPartOfIdentifier" = Field(None)


class NewOrganizationPartOfIdentifier(RedoxAbstractModel):

    System: Union[str, None] = Field(None)
    Type: Union[str, None] = Field(None)
    Value: Union[str, None] = Field(None)


class NewOrganizationType(RedoxAbstractModel):

    System: Union[str, None] = Field(None)
    Value: Union[str, None] = Field(None)


New.update_forward_refs()
NewMeta.update_forward_refs()
NewOrganization.update_forward_refs()
NewOrganizationContact.update_forward_refs()
NewOrganizationEndpoint.update_forward_refs()
NewOrganizationEndpointAttributes.update_forward_refs()
NewOrganizationPartOf.update_forward_refs()



# -*- coding: utf-8 -*-
# ----  AUTO-GENERATED BY redox_lib_gen. DO NOT MODIFY MANUALLY!!  ---- #

from typing import List, Union

from pydantic import Field

from ..abstract_base import EventTypeAbstractModel, RedoxAbstractModel
from ..field_types import Number


class Update(EventTypeAbstractModel):

    Action: str = Field(...)
    Directory: str = Field(...)
    Meta: "UpdateMeta" = Field(...)
    Organizations: List["UpdateOrganization"] = Field(...)


class UpdateMeta(RedoxAbstractModel):

    DataModel: str = Field(...)
    Destinations: List["UpdateMetaDestination"] = Field(None)
    EventDateTime: Union[str, None] = Field(None)
    EventType: str = Field(...)
    FacilityCode: Union[str, None] = Field(None)
    Logs: List["UpdateMetaLog"] = Field(None)
    Message: "UpdateMetaMessage" = Field(None)
    Source: "UpdateMetaSource" = Field(None)
    Test: Union[bool, None] = Field(None)
    Transmission: "UpdateMetaTransmission" = Field(None)


class UpdateMetaDestination(RedoxAbstractModel):

    ID: Union[str, None] = Field(None)
    Name: Union[str, None] = Field(None)


class UpdateMetaLog(RedoxAbstractModel):

    AttemptID: Union[str, None] = Field(None)
    ID: Union[str, None] = Field(None)


class UpdateMetaMessage(RedoxAbstractModel):

    ID: Union[Number, None] = Field(None)


class UpdateMetaSource(RedoxAbstractModel):

    ID: Union[str, None] = Field(None)
    Name: Union[str, None] = Field(None)


class UpdateMetaTransmission(RedoxAbstractModel):

    ID: Union[Number, None] = Field(None)


class UpdateOrganization(RedoxAbstractModel):

    Active: bool = Field(...)
    Address: "UpdateOrganizationAddress" = Field(None)
    Aliases: List[str] = Field(None)
    Contacts: List["UpdateOrganizationContact"] = Field(None)
    DestinationID: Union[str, None] = Field(None)
    Endpoints: List["UpdateOrganizationEndpoint"] = Field(None)
    Identifiers: List["UpdateOrganizationIdentifier"] = Field(None)
    Name: str = Field(...)
    PartOf: "UpdateOrganizationPartOf" = Field(None)
    Type: "UpdateOrganizationType" = Field(None)


class UpdateOrganizationAddress(RedoxAbstractModel):

    City: Union[str, None] = Field(None)
    Country: Union[str, None] = Field(None)
    County: Union[str, None] = Field(None)
    State: Union[str, None] = Field(None)
    StreetAddress: Union[str, None] = Field(None)
    ZIP: Union[str, None] = Field(None)


class UpdateOrganizationContact(RedoxAbstractModel):

    EmailAddresses: List[str] = Field(None)
    Name: Union[str, None] = Field(None)
    PhoneNumber: "UpdateOrganizationContactPhoneNumber" = Field(None)
    Purpose: Union[str, None] = Field(None)


class UpdateOrganizationContactPhoneNumber(RedoxAbstractModel):

    Home: Union[str, None] = Field(None)
    Mobile: Union[str, None] = Field(None)
    Work: Union[str, None] = Field(None)


class UpdateOrganizationEndpoint(RedoxAbstractModel):

    Address: Union[str, None] = Field(None)
    Attributes: "UpdateOrganizationEndpointAttributes" = Field(None)
    ConnectionType: "UpdateOrganizationEndpointConnectionType" = Field(None)
    Identifiers: List["UpdateOrganizationEndpointIdentifier"] = Field(None)
    MIMEType: Union[str, None] = Field(None)
    Name: Union[str, None] = Field(None)


class UpdateOrganizationEndpointAttributes(RedoxAbstractModel):

    Actor: "UpdateOrganizationEndpointAttributesActor" = Field(None)
    PurposeOfUse: List["UpdateOrganizationEndpointAttributesPurposeOfUse"] = Field(None)
    Roles: List["UpdateOrganizationEndpointAttributesRole"] = Field(None)
    Transaction: Union[str, None] = Field(None)
    UseCases: List["UpdateOrganizationEndpointAttributesUseCase"] = Field(None)
    Version: "UpdateOrganizationEndpointAttributesVersion" = Field(None)


class UpdateOrganizationEndpointAttributesActor(RedoxAbstractModel):

    System: Union[str, None] = Field(None)
    Value: Union[str, None] = Field(None)


class UpdateOrganizationEndpointAttributesPurposeOfUse(RedoxAbstractModel):

    System: Union[str, None] = Field(None)
    Value: Union[str, None] = Field(None)


class UpdateOrganizationEndpointAttributesRole(RedoxAbstractModel):

    System: Union[str, None] = Field(None)
    Value: Union[str, None] = Field(None)


class UpdateOrganizationEndpointAttributesUseCase(RedoxAbstractModel):

    System: Union[str, None] = Field(None)
    Value: Union[str, None] = Field(None)


class UpdateOrganizationEndpointAttributesVersion(RedoxAbstractModel):

    System: Union[str, None] = Field(None)
    Value: Union[str, None] = Field(None)


class UpdateOrganizationEndpointConnectionType(RedoxAbstractModel):

    System: Union[str, None] = Field(None)
    Value: Union[str, None] = Field(None)


class UpdateOrganizationEndpointIdentifier(RedoxAbstractModel):

    System: Union[str, None] = Field(None)
    Type: Union[str, None] = Field(None)
    Value: Union[str, None] = Field(None)


class UpdateOrganizationIdentifier(RedoxAbstractModel):

    ID: Union[str, None] = Field(None)
    IDType: Union[str, None] = Field(None)


class UpdateOrganizationPartOf(RedoxAbstractModel):

    Identifier: "UpdateOrganizationPartOfIdentifier" = Field(None)


class UpdateOrganizationPartOfIdentifier(RedoxAbstractModel):

    System: Union[str, None] = Field(None)
    Type: Union[str, None] = Field(None)
    Value: Union[str, None] = Field(None)


class UpdateOrganizationType(RedoxAbstractModel):

    System: Union[str, None] = Field(None)
    Value: Union[str, None] = Field(None)


Update.update_forward_refs()
UpdateMeta.update_forward_refs()
UpdateOrganization.update_forward_refs()
UpdateOrganizationContact.update_forward_refs()
UpdateOrganizationEndpoint.update_forward_refs()
UpdateOrganizationEndpointAttributes.update_forward_refs()
UpdateOrganizationPartOf.update_forward_refs()



# -*- coding: utf-8 -*-
# ----  AUTO-GENERATED BY redox_lib_gen. DO NOT MODIFY MANUALLY!!  ---- #

from typing import List, Union

from pydantic import Field

from ..abstract_base import EventTypeAbstractModel, RedoxAbstractModel
from ..field_types import Number


class AvailableSlotsResponse(EventTypeAbstractModel):

    AvailableSlots: List["AvailableSlotsResponseAvailableSlot"] = Field(...)
    Meta: "AvailableSlotsResponseMeta" = Field(...)


class AvailableSlotsResponseAvailableSlot(RedoxAbstractModel):

    DateTime: str = Field(...)
    Duration: Number = Field(...)
    ID: Union[str, None] = Field(None)
    Location: "AvailableSlotsResponseAvailableSlotLocation" = Field(None)
    Notes: List[str] = Field(None)
    Provider: "AvailableSlotsResponseAvailableSlotProvider" = Field(None)
    Reason: Union[str, None] = Field(None)


class AvailableSlotsResponseAvailableSlotLocation(RedoxAbstractModel):

    Department: Union[str, None] = Field(None)
    Facility: Union[str, None] = Field(None)
    Room: Union[str, None] = Field(None)
    Type: Union[str, None] = Field(None)


class AvailableSlotsResponseAvailableSlotProvider(RedoxAbstractModel):

    Address: "AvailableSlotsResponseAvailableSlotProviderAddress" = Field(None)
    Credentials: List[str] = Field(None)
    EmailAddresses: List[str] = Field(None)
    FirstName: Union[str, None] = Field(None)
    ID: Union[str, None] = Field(None)
    IDType: Union[str, None] = Field(None)
    LastName: Union[str, None] = Field(None)
    Location: "AvailableSlotsResponseAvailableSlotProviderLocation" = Field(None)
    PhoneNumber: "AvailableSlotsResponseAvailableSlotProviderPhoneNumber" = Field(None)


class AvailableSlotsResponseAvailableSlotProviderAddress(RedoxAbstractModel):

    City: Union[str, None] = Field(None)
    Country: Union[str, None] = Field(None)
    County: Union[str, None] = Field(None)
    State: Union[str, None] = Field(None)
    StreetAddress: Union[str, None] = Field(None)
    ZIP: Union[str, None] = Field(None)


class AvailableSlotsResponseAvailableSlotProviderLocation(RedoxAbstractModel):

    Department: Union[str, None] = Field(None)
    Facility: Union[str, None] = Field(None)
    Room: Union[str, None] = Field(None)
    Type: Union[str, None] = Field(None)


class AvailableSlotsResponseAvailableSlotProviderPhoneNumber(RedoxAbstractModel):

    Office: Union[str, None] = Field(None)


class AvailableSlotsResponseMeta(RedoxAbstractModel):

    DataModel: str = Field(...)
    Destinations: List["AvailableSlotsResponseMetaDestination"] = Field(None)
    EventDateTime: Union[str, None] = Field(None)
    EventType: str = Field(...)
    FacilityCode: Union[str, None] = Field(None)
    IsIncomplete: Union[bool, None] = Field(None)
    Logs: List["AvailableSlotsResponseMetaLog"] = Field(None)
    Message: "AvailableSlotsResponseMetaMessage" = Field(None)
    Source: "AvailableSlotsResponseMetaSource" = Field(None)
    Test: Union[bool, None] = Field(None)
    Transmission: "AvailableSlotsResponseMetaTransmission" = Field(None)


class AvailableSlotsResponseMetaDestination(RedoxAbstractModel):

    ID: Union[str, None] = Field(None)
    Name: Union[str, None] = Field(None)


class AvailableSlotsResponseMetaLog(RedoxAbstractModel):

    AttemptID: Union[str, None] = Field(None)
    ID: Union[str, None] = Field(None)


class AvailableSlotsResponseMetaMessage(RedoxAbstractModel):

    ID: Union[Number, None] = Field(None)


class AvailableSlotsResponseMetaSource(RedoxAbstractModel):

    ID: Union[str, None] = Field(None)
    Name: Union[str, None] = Field(None)


class AvailableSlotsResponseMetaTransmission(RedoxAbstractModel):

    ID: Union[Number, None] = Field(None)


AvailableSlotsResponse.update_forward_refs()
AvailableSlotsResponseAvailableSlot.update_forward_refs()
AvailableSlotsResponseAvailableSlotProvider.update_forward_refs()
AvailableSlotsResponseMeta.update_forward_refs()



# -*- coding: utf-8 -*-
# ----  AUTO-GENERATED BY redox_lib_gen. DO NOT MODIFY MANUALLY!!  ---- #

from typing import List, Union

from pydantic import Field

from ..abstract_base import EventTypeAbstractModel, RedoxAbstractModel
from ..field_types import Number


class DocumentGetResponse(EventTypeAbstractModel):

    Data: str = Field(...)
    Document: "DocumentGetResponseDocument" = Field(...)
    FileType: str = Field(...)
    Meta: "DocumentGetResponseMeta" = Field(...)


class DocumentGetResponseDocument(RedoxAbstractModel):

    ID: str = Field(...)


class DocumentGetResponseMeta(RedoxAbstractModel):

    DataModel: str = Field(...)
    Destinations: List["DocumentGetResponseMetaDestination"] = Field(None)
    EventDateTime: Union[str, None] = Field(None)
    EventType: str = Field(...)
    FacilityCode: Union[str, None] = Field(None)
    Logs: List["DocumentGetResponseMetaLog"] = Field(None)
    Message: "DocumentGetResponseMetaMessage" = Field(None)
    Source: "DocumentGetResponseMetaSource" = Field(None)
    Test: Union[bool, None] = Field(None)
    Transmission: "DocumentGetResponseMetaTransmission" = Field(None)


class DocumentGetResponseMetaDestination(RedoxAbstractModel):

    ID: Union[str, None] = Field(None)
    Name: Union[str, None] = Field(None)


class DocumentGetResponseMetaLog(RedoxAbstractModel):

    AttemptID: Union[str, None] = Field(None)
    ID: Union[str, None] = Field(None)


class DocumentGetResponseMetaMessage(RedoxAbstractModel):

    ID: Union[Number, None] = Field(None)


class DocumentGetResponseMetaSource(RedoxAbstractModel):

    ID: Union[str, None] = Field(None)
    Name: Union[str, None] = Field(None)


class DocumentGetResponseMetaTransmission(RedoxAbstractModel):

    ID: Union[Number, None] = Field(None)


DocumentGetResponse.update_forward_refs()
DocumentGetResponseMeta.update_forward_refs()
